import { __decorate, __metadata } from 'tslib';
import * as i0 from '@angular/core';
import { Directive, Input, HostBinding, NgModule } from '@angular/core';
import * as i1 from 'ng-devui/utils';
import { WithConfig } from 'ng-devui/utils';
import { CommonModule } from '@angular/common';

class TextareaDirective {
    get gray() {
        return this.styleType === 'gray';
    }
    constructor(devConfigService, el, render) {
        this.devConfigService = devConfigService;
        this.el = el;
        this.render = render;
        this.maxLengthBlocker = false;
        this.resize = 'none';
        this.styleType = 'default';
    }
    ngAfterViewInit() {
        if (this.maxLengthBlocker) {
            this.checkMaxLength = this.render.listen(this.el.nativeElement, 'compositionupdate', () => {
                /**
                 * 通过失焦中断composition输入事件规避chrome textarea中文符号输入超出最大宽度问题，如浏览器修复该问题可移除此方法
                 * 复现步骤：
                 * 1. 输若干入内容
                 * 2. 回车换行
                 * 3. 粘贴内容至最大长度
                 * 4. 输入中文等触发composition事件输入法的符号
                 */
                const max = this.el.nativeElement.maxLength;
                const len = (this.el.nativeElement.textContent || this.el.nativeElement.value).length;
                if (max <= len) {
                    this.el.nativeElement.blur();
                    this.el.nativeElement.focus();
                }
            });
        }
    }
    ngOnDestroy() {
        if (this.checkMaxLength) {
            this.checkMaxLength();
        }
    }
}
TextareaDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TextareaDirective, deps: [{ token: i1.DevConfigService }, { token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive });
TextareaDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.1.5", type: TextareaDirective, selector: "[dTextarea]", inputs: { maxLengthBlocker: "maxLengthBlocker", resize: "resize", error: "error", styleType: "styleType" }, host: { properties: { "style.resize": "this.resize", "class.error": "this.error", "class.devui-gray-style": "this.gray" } }, exportAs: ["dTextarea"], ngImport: i0 });
__decorate([
    WithConfig(),
    __metadata("design:type", Object)
], TextareaDirective.prototype, "styleType", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TextareaDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[dTextarea]',
                    exportAs: 'dTextarea',
                }]
        }], ctorParameters: function () { return [{ type: i1.DevConfigService }, { type: i0.ElementRef }, { type: i0.Renderer2 }]; }, propDecorators: { maxLengthBlocker: [{
                type: Input
            }], resize: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['style.resize']
            }], error: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.error']
            }], styleType: [{
                type: Input
            }], gray: [{
                type: HostBinding,
                args: ['class.devui-gray-style']
            }] } });

class TextareaModule {
}
TextareaModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TextareaModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
TextareaModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.1.5", ngImport: i0, type: TextareaModule, declarations: [TextareaDirective], imports: [CommonModule], exports: [TextareaDirective] });
TextareaModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TextareaModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: TextareaModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                    ],
                    exports: [TextareaDirective],
                    declarations: [TextareaDirective],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { TextareaDirective, TextareaModule };
//# sourceMappingURL=ng-devui-textarea.mjs.map
