import * as i3 from '@angular/common';
import { DOCUMENT, CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Injectable, Inject, TemplateRef, Component, Input, NgModule } from '@angular/core';
import { Subject, BehaviorSubject, fromEventPattern } from 'rxjs';
import { takeUntil } from 'rxjs/operators';
import * as i2 from 'ng-devui/i18n';
import * as i4 from 'ng-devui/button';
import { ButtonModule } from 'ng-devui/button';
import * as i5 from 'ng-devui/utils';
import { SafePipeModule } from 'ng-devui/utils';
import * as i1 from 'ng-devui/overlay-container';
import * as i5$1 from 'ng-devui/dropdown';
import { DropDownModule } from 'ng-devui/dropdown';

const ARROW_WIDTH = 8;
const PANEL_TO_ELEMENT = 10;
class PanelPostion {
    constructor(document) {
        this.document = document;
    }
    calculateAvailablePosition(curStepRect, panelRect) {
        if (this.step.position !== undefined) {
            this.availablePosition = this.step.position.split('-')[0];
        }
        else {
            if (curStepRect.bottom + panelRect.height + PANEL_TO_ELEMENT <= this.document.documentElement.clientHeight) {
                this.availablePosition = 'bottom';
            }
            else if (curStepRect.top - panelRect.height - PANEL_TO_ELEMENT > 0) {
                this.availablePosition = 'top';
            }
            else if (curStepRect.right + panelRect.width + PANEL_TO_ELEMENT <= this.document.documentElement.clientWidth) {
                this.availablePosition = 'right';
            }
            else if (curStepRect.left - panelRect.width - PANEL_TO_ELEMENT > 0) {
                this.availablePosition = 'left';
            }
        }
    }
    calculateTopAndLeft(curStepRect, panelRect) {
        if (this.availablePosition === 'bottom') {
            this.top = curStepRect.bottom + PANEL_TO_ELEMENT;
            this.arrowTopBias = ARROW_WIDTH / 2;
        }
        else if (this.availablePosition === 'top') {
            this.arrowTopBias = panelRect.height - ARROW_WIDTH / 2;
            this.top = curStepRect.top - panelRect.height - PANEL_TO_ELEMENT;
        }
        else if (this.availablePosition === 'right') {
            this.left = curStepRect.right + PANEL_TO_ELEMENT;
            this.arrowLeftBias = -ARROW_WIDTH / 2;
        }
        else if (curStepRect.left - panelRect.width - PANEL_TO_ELEMENT > 0) {
            this.left = curStepRect.left - panelRect.width - PANEL_TO_ELEMENT;
            this.arrowLeftBias = panelRect.width - ARROW_WIDTH / 2;
        }
    }
    calculateAlignDirection(curStepRect, panelRect) {
        if (this.step.position !== undefined) {
            this.alignDirection = this.step.position.split('-')[1] || 'middle';
        }
        else {
            if (this.availablePosition === 'bottom' || this.availablePosition === 'top') {
                this.calculateTopBottomAlign(curStepRect, panelRect);
            }
            else if (this.availablePosition === 'left' || this.availablePosition === 'right') {
                this.calculateLeftRightAlign(curStepRect, panelRect);
            }
        }
    }
    calculateTopBottomAlign(curStepRect, panelRect) {
        if (panelRect.width < curStepRect.width ||
            (curStepRect.left + curStepRect.width / 2 - panelRect.width / 2 > 0 &&
                curStepRect.left + curStepRect.width / 2 + panelRect.width / 2 < this.document.documentElement.clientWidth)) {
            this.alignDirection = 'middle';
        }
        else if (curStepRect.left + panelRect.width < this.document.documentElement.clientWidth) {
            this.alignDirection = 'left';
        }
        else if (curStepRect.right - panelRect.width > 0) {
            this.alignDirection = 'right';
        }
    }
    calculateLeftRightAlign(curStepRect, panelRect) {
        if (panelRect.height < curStepRect.height ||
            (curStepRect.top + curStepRect.height / 2 - panelRect.height / 2 > 0 &&
                curStepRect.top + curStepRect.height / 2 + panelRect.height / 2 < this.document.documentElement.clientHeight)) {
            this.alignDirection = 'middle';
        }
        else if (curStepRect.top + panelRect.height < this.document.documentElement.clientWidth) {
            this.alignDirection = 'top';
        }
        else if (curStepRect.bottom - panelRect.height > 0) {
            this.alignDirection = 'bottom';
        }
    }
    calculateBias(curStepRect, panelRect) {
        if (this.availablePosition === 'bottom' || this.availablePosition === 'top') {
            this.calculateTopBottomBias(curStepRect, panelRect);
        }
        else if (this.availablePosition === 'left' || this.availablePosition === 'right') {
            this.calculateLeftRightBias(curStepRect, panelRect);
        }
    }
    calculateTopBottomBias(curStepRect, panelRect) {
        if (this.alignDirection === 'middle') {
            this.left = curStepRect.left + curStepRect.width / 2 - panelRect.width / 2;
            this.arrowLeftBias = panelRect.width / 2 - ARROW_WIDTH / 2;
        }
        else if (this.alignDirection === 'left') {
            this.left = curStepRect.left;
            this.arrowLeftBias = PANEL_TO_ELEMENT + ARROW_WIDTH;
        }
        else if (this.alignDirection === 'right') {
            this.left = curStepRect.right - panelRect.width;
            this.arrowLeftBias = panelRect.width - PANEL_TO_ELEMENT - ARROW_WIDTH;
        }
    }
    calculateLeftRightBias(curStepRect, panelRect) {
        if (this.alignDirection === 'middle') {
            this.top = curStepRect.top + curStepRect.height / 2 - panelRect.height / 2;
            this.arrowTopBias = panelRect.height / 2;
        }
        else if (this.alignDirection === 'top') {
            this.top = curStepRect.top;
            this.arrowTopBias = PANEL_TO_ELEMENT + ARROW_WIDTH;
        }
        else if (this.alignDirection === 'bottom') {
            this.top = curStepRect.bottom - panelRect.height;
            this.arrowTopBias = panelRect.height - PANEL_TO_ELEMENT - ARROW_WIDTH;
        }
    }
    getRealClientRect(step) {
        var _a;
        const stepRect = (_a = step.element) === null || _a === void 0 ? void 0 : _a.getBoundingClientRect();
        const realRect = {
            top: (stepRect === null || stepRect === void 0 ? void 0 : stepRect.top) - ((step === null || step === void 0 ? void 0 : step.highlightOffset) ? step.highlightOffset[0] : 0),
            right: (stepRect === null || stepRect === void 0 ? void 0 : stepRect.right) + ((step === null || step === void 0 ? void 0 : step.highlightOffset) ? step.highlightOffset[1] : 0),
            left: (stepRect === null || stepRect === void 0 ? void 0 : stepRect.left) - ((step === null || step === void 0 ? void 0 : step.highlightOffset) ? step.highlightOffset[3] : 0),
            bottom: (stepRect === null || stepRect === void 0 ? void 0 : stepRect.bottom) + ((step === null || step === void 0 ? void 0 : step.highlightOffset) ? step.highlightOffset[2] : 0),
            width: (stepRect === null || stepRect === void 0 ? void 0 : stepRect.width) + ((step === null || step === void 0 ? void 0 : step.highlightOffset) ? step.highlightOffset[3] + step.highlightOffset[1] : 0),
            height: (stepRect === null || stepRect === void 0 ? void 0 : stepRect.height) + ((step === null || step === void 0 ? void 0 : step.highlightOffset) ? step.highlightOffset[0] + step.highlightOffset[2] : 0),
        };
        return realRect;
    }
    calculatePosition(step) {
        const panel = this.document.querySelector('.user-guide-panel');
        const panelRect = panel.getBoundingClientRect();
        this.step = step;
        const curStepRect = this.getRealClientRect(step);
        this.calculateAvailablePosition(curStepRect, panelRect);
        this.calculateTopAndLeft(curStepRect, panelRect);
        this.calculateAlignDirection(curStepRect, panelRect);
        this.calculateBias(curStepRect, panelRect);
        const panelArrow = this.document.querySelector('.devui-user-guide-panel-arrow');
        if (panelArrow) {
            panelArrow.style.top = `${this.arrowTopBias}px`;
            panelArrow.style.left = `${this.arrowLeftBias}px`;
        }
        panel.style.cssText = `
          top: ${this.top}px;
          left: ${this.left}px;
        `;
    }
}

function addBorderAnimation(document) {
    const topBorder = document.querySelector('.user-guide-top-border');
    topBorder.classList.add('emphasize-top-animation');
    const bottomBorder = document.querySelector('.user-guide-bottom-border');
    bottomBorder.classList.add('emphasize-bottom-animation');
    const leftBorder = document.querySelector('.user-guide-left-border');
    leftBorder.classList.add('emphasize-left-animation');
    const rightBorder = document.querySelector('.user-guide-right-border');
    rightBorder.classList.add('emphasize-right-animation');
}
function removeBorderAnimation(document) {
    const topBorder = document.querySelector('.user-guide-top-border');
    topBorder.classList.remove('emphasize-top-animation');
    const bottomBorder = document.querySelector('.user-guide-bottom-border');
    bottomBorder.classList.remove('emphasize-bottom-animation');
    const leftBorder = document.querySelector('.user-guide-left-border');
    leftBorder.classList.remove('emphasize-left-animation');
    const rightBorder = document.querySelector('.user-guide-right-border');
    rightBorder.classList.remove('emphasize-right-animation');
}

function disableClick(e) {
    e.preventDefault();
    e.stopPropagation();
}
function documentRealHeight(document) {
    return Math.max(document.body.scrollHeight, document.documentElement.scrollHeight, document.body.offsetHeight, document.documentElement.offsetHeight, document.body.clientHeight, document.documentElement.clientHeight);
}

class UserGuideCoreService {
    constructor(rendererFactory2, doc) {
        this.rendererFactory2 = rendererFactory2;
        this.doc = doc;
        this.steps = []; // 用户输入的指引步骤
        this.stepsDetails = []; // 经过处理加入细节的指引步骤
        this.isStart = false;
        this._destory = new Subject();
        this.interactableEvent = {
            eventType: null,
            element: null,
            eventFunction: null
        };
        this._showOverlayState = {
            showMaskLayer: false,
            showNormalOverlay: false,
            showTopOverlay: false,
            showBottomOverlay: false,
            showLeftOverlay: false,
            showRightOverlay: false,
            showBorder: false
        };
        this.curContent = new BehaviorSubject('start');
        this.curSubContent = new BehaviorSubject('');
        this.curStep = new BehaviorSubject(-1);
        this.canNext = new BehaviorSubject(true);
        this.canPrev = new BehaviorSubject(true);
        this.canFinish = new BehaviorSubject(false);
        this.isFinished = new BehaviorSubject(false);
        this.showButtons = new BehaviorSubject(true);
        this.showOverlayState = new BehaviorSubject(this._showOverlayState);
        this.showOperateZone = new BehaviorSubject(false);
        this.showPrevButton = new BehaviorSubject(true);
        this.curStepType = new BehaviorSubject('normal');
        const renderer = this.rendererFactory2.createRenderer(null, null);
        this.document = this.doc;
        this.panelPostion = new PanelPostion(this.document);
        this.createOnResizeObservable(renderer);
        this.onResize.subscribe((e) => {
            if (this.isStart && this.stepsDetails[this.currentStep].type !== 'display') {
                this.updateCurrentStepElement();
                this.setStepShow(this.currentType, this.currentStep);
            }
        });
        this.curStep.subscribe(index => {
            if (index !== -1) {
                this.canChange(index).then((canChange) => {
                    if (canChange) {
                        this.changeStep();
                    }
                });
            }
        });
    }
    ngOnDestroy() {
        this._destory.next();
        this._destory.complete();
        if (this.curContent) {
            this.curContent.unsubscribe();
        }
        if (this.curSubContent) {
            this.curSubContent.unsubscribe();
        }
        if (this.curStep) {
            this.curStep.unsubscribe();
        }
        if (this.canNext) {
            this.canNext.unsubscribe();
        }
        if (this.canPrev) {
            this.canPrev.unsubscribe();
        }
        if (this.canFinish) {
            this.canFinish.unsubscribe();
        }
        if (this.isFinished) {
            this.isFinished.unsubscribe();
        }
        if (this.showButtons) {
            this.showButtons.unsubscribe();
        }
        if (this.showOverlayState) {
            this.showOverlayState.unsubscribe();
        }
        if (this.showOperateZone) {
            this.showOperateZone.unsubscribe();
        }
        if (this.curStepType) {
            this.curStepType.unsubscribe();
        }
        if (this.showPrevButton) {
            this.showPrevButton.unsubscribe();
        }
    }
    start() {
        if (this.steps.length === 0) {
            return;
        }
        this.generateStepsDetails();
        this.setInitialState();
    }
    generateStepsDetails() {
        this.steps.forEach((item) => {
            var _a;
            if (item.element === undefined) {
                this.stepsDetails.push({
                    title: item.title,
                    content: item.content,
                    type: 'display',
                    beforeChange: item === null || item === void 0 ? void 0 : item.beforeChange,
                    showPrevButton: (item === null || item === void 0 ? void 0 : item.showPrevButton) === undefined ? true : item.showPrevButton
                });
            }
            else {
                const rect = (_a = (this.document.getElementById(item.element) || this.document.querySelector(item.element))) === null || _a === void 0 ? void 0 : _a.getBoundingClientRect();
                this.stepsDetails.push({
                    element: this.document.getElementById(item.element) || this.document.querySelector(item.element),
                    title: item.title,
                    content: item.content,
                    position: item.position,
                    highlightOffset: item === null || item === void 0 ? void 0 : item.highlightOffset,
                    top: rect === null || rect === void 0 ? void 0 : rect.top,
                    left: rect === null || rect === void 0 ? void 0 : rect.left,
                    width: rect === null || rect === void 0 ? void 0 : rect.width,
                    height: rect === null || rect === void 0 ? void 0 : rect.height,
                    type: item.type === undefined ? 'normal' : item.type,
                    eventType: item === null || item === void 0 ? void 0 : item.eventType,
                    inputData: item === null || item === void 0 ? void 0 : item.inputData,
                    waitingTime: item === null || item === void 0 ? void 0 : item.waitingTime,
                    beforeChange: item === null || item === void 0 ? void 0 : item.beforeChange,
                    showPrevButton: (item === null || item === void 0 ? void 0 : item.showPrevButton) === undefined ? true : item.showPrevButton
                });
            }
        });
    }
    setInitialState() {
        this.isStart = true;
        // 初始状态,令currentStep为-1
        this.currentStep = -1;
        this.prevStep = -2;
        this.nextStep = 0;
    }
    setSteps(steps) {
        this.steps = steps;
    }
    setExitFunction(exit) {
        this.onExit = exit;
    }
    updateNextStepElement() {
        var _a, _b;
        for (let i = this.nextStep; i < this.steps.length; i++) {
            if (this.stepsDetails[i].type !== 'display') {
                this.stepsDetails[i].element = this.document.getElementById(this.steps[i].element)
                    || this.document.querySelector(this.steps[i].element);
                const rect = (_b = (_a = this.stepsDetails[i]) === null || _a === void 0 ? void 0 : _a.element) === null || _b === void 0 ? void 0 : _b.getBoundingClientRect();
                this.stepsDetails[i].top = rect === null || rect === void 0 ? void 0 : rect.top;
                this.stepsDetails[i].left = rect === null || rect === void 0 ? void 0 : rect.left;
                this.stepsDetails[i].width = rect === null || rect === void 0 ? void 0 : rect.width;
                this.stepsDetails[i].height = rect === null || rect === void 0 ? void 0 : rect.height;
            }
        }
    }
    updateCurrentStepElement() {
        const cur = this.currentStep;
        this.stepsDetails[cur].element = this.document.getElementById(this.steps[cur].element)
            || this.document.querySelector(this.steps[cur].element);
        if (this.stepsDetails[cur].element) {
            const rect = this.stepsDetails[cur].element.getBoundingClientRect();
            const hasHighlightOffset = this.stepsDetails[cur].highlightOffset;
            this.stepsDetails[cur].top = (rect === null || rect === void 0 ? void 0 : rect.top) - (hasHighlightOffset ? this.stepsDetails[cur].highlightOffset[0] : 0);
            this.stepsDetails[cur].left = (rect === null || rect === void 0 ? void 0 : rect.left) - (hasHighlightOffset ? this.stepsDetails[cur].highlightOffset[3] : 0);
            this.stepsDetails[cur].width =
                (rect === null || rect === void 0 ? void 0 : rect.width) + (hasHighlightOffset ? this.stepsDetails[cur].highlightOffset[3] + this.stepsDetails[cur].highlightOffset[1] : 0);
            this.stepsDetails[cur].height =
                (rect === null || rect === void 0 ? void 0 : rect.height) + (hasHighlightOffset ? this.stepsDetails[cur].highlightOffset[0] + this.stepsDetails[cur].highlightOffset[2] : 0);
        }
    }
    canChange(index) {
        var _a;
        let changeResult = Promise.resolve(true);
        if (((_a = this.stepsDetails[index]) === null || _a === void 0 ? void 0 : _a.beforeChange) !== undefined) {
            const result = this.stepsDetails[index].beforeChange();
            if (typeof result !== 'undefined') {
                if (result.then) {
                    changeResult = result;
                }
                else if (result.subscribe) {
                    changeResult = result.toPromise();
                }
                else {
                    changeResult = Promise.resolve(result);
                }
            }
        }
        return changeResult;
    }
    next() {
        this.changeStepState('forward');
    }
    prev() {
        this.changeStepState('backward');
    }
    exit() {
        if (this.currentStep === this.steps.length - 1) {
            this.isFinished.next(true);
            this.canFinish.next(false);
        }
        localStorage.setItem('devui-user-guide-last-step', this.currentStep);
        if (this.interactableEvent.eventType !== null) {
            this.interactableEvent.element.forEach((item, index) => {
                item.removeEventListener(this.interactableEvent.eventType[index], this.interactableEvent.eventFunction[index]);
            });
        }
        this.clearInteractableEvent();
        if (this.onExit) {
            this.onExit();
        }
        this.currentType = undefined;
        this.steps = [];
        this.stepsDetails = [];
        this.isStart = false;
        this.onExit = undefined;
    }
    goStep(index) {
        if (index > this.currentStep) {
            this.changeStepState('forward', Math.abs(this.currentStep - index));
        }
        else if (index < this.currentStep) {
            this.changeStepState('backward', Math.abs(this.currentStep - index));
        }
    }
    onBeforeChange(index) {
        this.clearInteractableEvent();
        this.registerInteractableEvent(index);
    }
    getCurrentStep() {
        return this.currentStep;
    }
    getCurrentDirection() {
        return this.currentDirection;
    }
    getStepLength() {
        return this.steps.length;
    }
    registerInteractableEvent(index) {
        if (this.stepsDetails[index].eventType === 'clickable') {
            this.registerClickEvent(index);
        }
        else if (this.stepsDetails[index].eventType === 'inputable') {
            this.registerInputEvent(index);
        }
        else if (this.stepsDetails[index].eventType === 'exit') {
            this.registerExitEvent(index);
        }
    }
    clearInteractableEvent() {
        if (this.interactableEvent.eventType !== null) {
            this.interactableEvent.eventType = null;
            this.interactableEvent.element = null;
            this.interactableEvent.eventFunction = null;
            this.showButtons.next(true);
            this.showOperateZone.next(false);
            this.canPrev.next(false);
            removeBorderAnimation(this.document);
        }
    }
    registerClickEvent(index) {
        const clickElement = this.stepsDetails[index].element;
        this.interactableEvent.eventType = ['click'];
        this.interactableEvent.element = [clickElement];
        this.interactableEvent.eventFunction = [this.clickEventHandle.bind(this)];
        this.showButtons.next(false);
        addBorderAnimation(this.document);
        clickElement.addEventListener('click', this.interactableEvent.eventFunction[0], { once: true });
    }
    clickEventHandle() {
        const waitingTime = this.stepsDetails[this.currentStep].waitingTime || 300;
        this.document.body.addEventListener('click', disableClick, true);
        setTimeout(() => {
            this.updateNextStepElement();
            this.next();
        }, waitingTime);
        setTimeout(() => {
            this.document.body.removeEventListener('click', disableClick, true);
        }, 1000);
    }
    registerInputEvent(index) {
        this.showOperateZone.next(true);
        setTimeout(() => {
            const inputElement = this.document.querySelector('.operate-zone');
            this.interactableEvent.eventType = ['input', 'click'];
            this.interactableEvent.element = [this.stepsDetails[this.currentStep].element, inputElement];
            this.interactableEvent.eventFunction = [this.inputEventHandle.bind(this), this.inputOperateZoneHandle.bind(this)];
            this.showButtons.next(false);
            addBorderAnimation(this.document);
            this.stepsDetails[this.currentStep].element.addEventListener('input', this.interactableEvent.eventFunction[0], { once: true });
            inputElement.addEventListener('click', this.interactableEvent.eventFunction[1], { once: true });
        });
    }
    inputEventHandle() {
        const operateZone = this.document.querySelector('.operate-zone');
        operateZone.innerHTML = '<p><i class="icon icon-right-o" style="color: rgb(61, 204, 166); padding-right: 4px;"></i>Good！</p>';
        this.showButtons.next(true);
    }
    inputOperateZoneHandle() {
        this.stepsDetails[this.currentStep].element.value = this.stepsDetails[this.currentStep].inputData;
        const operateZone = this.document.querySelector('.operate-zone');
        operateZone.innerHTML = '<p><i class="icon icon-right-o" style="color: rgb(61, 204, 166); padding-right: 4px;"></i>Good！</p>';
        this.showButtons.next(true);
    }
    registerExitEvent(index) {
        const clickElement = this.stepsDetails[index].element;
        this.interactableEvent.eventType = ['click'];
        this.interactableEvent.element = [clickElement];
        this.interactableEvent.eventFunction = [this.ExitEventHandle.bind(this)];
        addBorderAnimation(this.document);
        this.showButtons.next(false);
        clickElement.addEventListener('click', this.interactableEvent.eventFunction[0], { once: true });
    }
    ExitEventHandle() {
        this.generateOverlay('display');
        this.currentType = 'display';
        const panel = this.document.querySelector('.user-guide-panel');
        panel.style.cssText = `
    top: 50%;
    left:50%;
    transform: translate(-50%, -50%);
    `;
        const closeButton = this.document.querySelector('.user-guide-panel-close');
        closeButton.style.display = 'none';
        const carouselDots = this.document.querySelector('.devui-carousel-dots');
        if (carouselDots) {
            carouselDots.style.display = 'none';
        }
        const operateZone = this.document.querySelector('.user-guide-panel-multiple-body');
        operateZone.style.maxWidth = 'unset';
        operateZone.innerHTML = `<div style="text-align: center;">
      <i class="icon icon-right-o" style="color: rgb(61, 204, 166); font-size: 36px;"></i>
      <p style="margin-top: 4px; font-size: 16px;">Congratulations！</p></div>`;
        setTimeout(() => {
            this.exit();
        }, 2000);
    }
    ChooseProperOverlay() {
        if (this.stepsDetails[this.currentStep].type !== this.currentType) {
            this.generateOverlay(this.stepsDetails[this.currentStep].type);
            this.currentType = this.stepsDetails[this.currentStep].type;
        }
    }
    generateOverlay(type) {
        switch (type) {
            case 'normal':
                this.generateNormalOverlay();
                break;
            case 'interactable':
                this.generateInteractableOverlay();
                break;
            case 'display':
                this.generateDisplayOverlay();
                break;
            case 'tip':
                this.generateTipOverlay();
                break;
            default:
                break;
        }
    }
    setStepShow(type, index) {
        this.curStepType.next(type);
        switch (type) {
            case 'normal':
                this.setNormalStepShow(index);
                break;
            case 'interactable':
                this.setInteractableStepShow(index);
                break;
            case 'display':
                this.setDisplayStepShow(index);
                break;
            case 'tip':
                this.setTipStepShow(index);
                break;
            default:
                break;
        }
    }
    changeStepState(direction, times = 1) {
        this.currentDirection = direction;
        for (let i = 0; i < times; i++) {
            if (direction === 'forward' && this.nextStep < this.steps.length) {
                this.prevStep = this.currentStep;
                this.currentStep++;
                this.nextStep = this.currentStep + 1;
            }
            else if (direction === 'backward' && this.prevStep >= 0) {
                this.nextStep = this.currentStep;
                this.currentStep--;
                this.prevStep = this.currentStep - 1;
            }
        }
        this.curStep.next(this.currentStep);
        this.canNext.next(false);
        this.canPrev.next(false);
    }
    changeStep() {
        if (this.currentStep >= 0 && this.currentStep < this.steps.length) {
            this.onBeforeChange(this.currentStep);
            this.ChooseProperOverlay();
            this.updateCurrentStepElement();
            this.setStepShow(this.currentType, this.currentStep);
        }
        if (this.nextStep === this.steps.length) {
            this.canNext.next(false);
            this.canFinish.next(true);
        }
        else {
            this.canNext.next(true);
            this.canFinish.next(false);
        }
        if (this.prevStep === -1) {
            this.canPrev.next(false);
        }
        else {
            this.canPrev.next(true);
        }
    }
    generateNormalOverlay() {
        this._showOverlayState = {
            showMaskLayer: false,
            showNormalOverlay: true,
            showTopOverlay: true,
            showBottomOverlay: true,
            showLeftOverlay: true,
            showRightOverlay: true,
            showBorder: false
        };
        this.showOverlayState.next(this._showOverlayState);
    }
    setNormalStepShow(index) {
        this.setInteractableStepShow(index);
    }
    generateInteractableOverlay() {
        this._showOverlayState = {
            showMaskLayer: false,
            showNormalOverlay: false,
            showTopOverlay: true,
            showBottomOverlay: true,
            showLeftOverlay: true,
            showRightOverlay: true,
            showBorder: true
        };
        this.showOverlayState.next(this._showOverlayState);
    }
    setInteractableStepShow(index) {
        const topOverlay = this.document.querySelector('.user-guide-top-overlay');
        topOverlay.style.cssText = `
      height: ${this.stepsDetails[index].top}px;
      `;
        const bottomOverlay = this.document.querySelector('.user-guide-bottom-overlay');
        bottomOverlay.style.cssText = `
      top: ${this.stepsDetails[index].top + this.stepsDetails[index].height}px;
      height: ${documentRealHeight(this.document) - (this.stepsDetails[index].top + this.stepsDetails[index].height)}px;
      `;
        const leftOverlay = this.document.querySelector('.user-guide-left-overlay');
        leftOverlay.style.cssText = `
      top: ${this.stepsDetails[index].top}px;
      width: ${this.stepsDetails[index].left}px;
      height: ${this.stepsDetails[index].height}px;
      `;
        const rightOverlay = this.document.querySelector('.user-guide-right-overlay');
        rightOverlay.style.cssText = `
      top: ${this.stepsDetails[index].top}px;
      left: ${this.stepsDetails[index].left + this.stepsDetails[index].width}px;
      width: ${this.document.documentElement.clientWidth - (this.stepsDetails[index].left + this.stepsDetails[index].width)}px;
      height: ${this.stepsDetails[index].height}px;
      `;
        const topBorder = this.document.querySelector('.user-guide-top-border');
        topBorder.style.cssText = `
      top: ${this.stepsDetails[index].top}px;
      left: ${this.stepsDetails[index].left}px;
      width: ${this.stepsDetails[index].width}px;
      `;
        const bottomBorder = this.document.querySelector('.user-guide-bottom-border');
        bottomBorder.style.cssText = `
      top: ${this.stepsDetails[index].top + this.stepsDetails[index].height}px;
      left: ${this.stepsDetails[index].left}px;
      width: ${this.stepsDetails[index].width}px;
      `;
        const leftBorder = this.document.querySelector('.user-guide-left-border');
        leftBorder.style.cssText = `
      top: ${this.stepsDetails[index].top}px;
      left: ${this.stepsDetails[index].left}px;
      height: ${this.stepsDetails[index].height}px;
      `;
        const rightBorder = this.document.querySelector('.user-guide-right-border');
        rightBorder.style.cssText = `
      top: ${this.stepsDetails[index].top}px;
      left: ${this.stepsDetails[index].left + this.stepsDetails[index].width}px;
      height: ${this.stepsDetails[index].height + 2}px;
      `;
        setTimeout(() => {
            this.panelPostion.calculatePosition(this.stepsDetails[this.currentStep]);
        }, 0);
        this.curContent.next(this.stepsDetails[index].title);
        this.curSubContent.next(this.stepsDetails[index].content);
        this.showPrevButton.next(this.stepsDetails[index].showPrevButton);
    }
    generateDisplayOverlay() {
        this._showOverlayState = {
            showMaskLayer: true,
            showNormalOverlay: false,
            showTopOverlay: false,
            showBottomOverlay: false,
            showLeftOverlay: false,
            showRightOverlay: false,
            showBorder: false
        };
        this.showOverlayState.next(this._showOverlayState);
    }
    setDisplayStepShow(index) {
        const panel = this.document.querySelector('.user-guide-panel');
        panel.style.cssText = `
    top: 50%;
    left:50%;
    transform: translate(-50%, -50%);
    `;
        this.curContent.next(this.stepsDetails[index].title);
        this.curSubContent.next(this.stepsDetails[index].content);
        this.showPrevButton.next(this.stepsDetails[index].showPrevButton);
    }
    generateTipOverlay() {
        this._showOverlayState = {
            showMaskLayer: false,
            showNormalOverlay: false,
            showTopOverlay: false,
            showBottomOverlay: false,
            showLeftOverlay: false,
            showRightOverlay: false,
            showBorder: false
        };
        this.showOverlayState.next(this._showOverlayState);
    }
    setTipStepShow(index) {
        this.setInteractableStepShow(index);
    }
    createOnResizeObservable(renderer) {
        let removeResizeEventListener;
        const createResizeEventListener = (handler) => {
            removeResizeEventListener = renderer.listen('window', 'resize', handler);
        };
        this.onResize = fromEventPattern(createResizeEventListener, () => removeResizeEventListener()).pipe(takeUntil(this._destory));
    }
}
UserGuideCoreService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideCoreService, deps: [{ token: i0.RendererFactory2 }, { token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Injectable });
UserGuideCoreService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideCoreService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideCoreService, decorators: [{
            type: Injectable
        }], ctorParameters: function () {
        return [{ type: i0.RendererFactory2 }, { type: undefined, decorators: [{
                        type: Inject,
                        args: [DOCUMENT]
                    }] }];
    } });

class UserGuideUIComponent {
    get contentTemplate() {
        return this.content;
    }
    get nextButtonType() {
        var _a;
        return (((_a = this.extraConfig) === null || _a === void 0 ? void 0 : _a.nextButtonType) || 'primary');
    }
    constructor(userGuideCoreService, i18n) {
        this.userGuideCoreService = userGuideCoreService;
        this.i18n = i18n;
        this.showDots = false;
        this.maxContentWidth = 320;
        this.isCover = true;
        this.showMaskLayer = false;
        this.showNormalOverlay = false;
        this.showTopOverlay = false;
        this.showBottomOverlay = false;
        this.showLeftOverlay = false;
        this.showRightOverlay = false;
        this.showBorder = false;
        this.showButtons = true;
        this.showOperateZone = false;
        this.showPrevButton = true;
        this.items = [];
    }
    ngOnInit() {
        this.userGuideCoreService.curContent.subscribe(item => { this.title = item; });
        this.userGuideCoreService.curSubContent.subscribe(item => { this.content = item; });
        this.userGuideCoreService.canNext.subscribe(item => { this.canNext = item; });
        this.userGuideCoreService.canPrev.subscribe(item => { this.canPrev = item; });
        this.userGuideCoreService.canFinish.subscribe(item => { this.canFinish = item; });
        this.userGuideCoreService.curStep.subscribe(item => { this.currentStep = item; });
        this.userGuideCoreService.curStepType.subscribe(item => { this.curStepType = item; });
        this.userGuideCoreService.showButtons.subscribe(item => { this.showButtons = item; });
        this.userGuideCoreService.showOperateZone.subscribe(item => { this.showOperateZone = item; });
        this.userGuideCoreService.showOverlayState.subscribe(item => {
            this.showMaskLayer = item.showMaskLayer;
            this.showNormalOverlay = item.showNormalOverlay;
            this.showTopOverlay = item.showTopOverlay;
            this.showBottomOverlay = item.showBottomOverlay;
            this.showLeftOverlay = item.showLeftOverlay;
            this.showRightOverlay = item.showRightOverlay;
            this.showBorder = item.showBorder;
        });
        this.userGuideCoreService.showPrevButton.subscribe(item => { this.showPrevButton = item; });
        this.stepsLength = this.userGuideCoreService.getStepLength();
        for (let i = 0; i < this.stepsLength; i++) {
            this.items.push(i);
        }
        this.i18nCommonText = this.i18n.getI18nText().userGuide;
        this.i18nSubscription = this.i18n.langChange().subscribe((data) => {
            this.i18nCommonText = data.userGuide;
        });
    }
    next() {
        this.userGuideCoreService.next();
    }
    prev() {
        this.userGuideCoreService.prev();
    }
    exit() {
        this.userGuideCoreService.exit();
        this.close();
    }
    close() {
    }
    switchStep(index) {
        this.userGuideCoreService.goStep(index);
    }
    disableClick(event) {
        event.preventDefault();
        event.stopPropagation();
    }
    isTemplateContent() {
        return this.content instanceof TemplateRef;
    }
    ngOnDestroy() {
        if (this.i18nSubscription) {
            this.i18nSubscription.unsubscribe();
        }
    }
}
UserGuideUIComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideUIComponent, deps: [{ token: UserGuideCoreService }, { token: i2.I18nService }], target: i0.ɵɵFactoryTarget.Component });
UserGuideUIComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.1.5", type: UserGuideUIComponent, selector: "d-user-guide-ui", inputs: { showDots: "showDots", maxContentWidth: "maxContentWidth", isCover: "isCover", extraConfig: "extraConfig" }, ngImport: i0, template: "<div [class.show-overlay]=\"showMaskLayer && isCover\" class=\"user-guide-mask-layer\"></div>\n<div [class.show-overlay]=\"showNormalOverlay && isCover\" class=\"user-guide-normal-overlay\"></div>\n\n<div [class.show-overlay]=\"showTopOverlay && isCover\" class=\"user-guide-top-overlay\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showBottomOverlay && isCover\" class=\"user-guide-bottom-overlay\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showLeftOverlay && isCover\" class=\"user-guide-left-overlay\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showRightOverlay && isCover\" class=\"user-guide-right-overlay\" (click)=\"disableClick($event)\"></div>\n\n<div [class.show-overlay]=\"showBorder && isCover\" class=\"user-guide-top-border\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showBorder && isCover\" class=\"user-guide-bottom-border\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showBorder && isCover\" class=\"user-guide-left-border\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showBorder && isCover\" class=\"user-guide-right-border\" (click)=\"disableClick($event)\"></div>\n\n<div class=\"user-guide-panel\">\n  <div\n    *ngIf=\"!isCover && (stepsLength !== 1 || curStepType !== 'tip') && curStepType !== 'display'\"\n    class=\"devui-user-guide-panel-arrow\"\n    [style.background-color]=\"extraConfig?.panelBackground\"\n  ></div>\n  <div\n    *ngIf=\"stepsLength !== 1 || curStepType !== 'tip'\"\n    id=\"devui-user-guide\"\n    class=\"user-guide-panel-multiple\"\n    [style.background]=\"extraConfig?.panelBackground\"\n  >\n    <div class=\"user-guide-panel-multiple-header\">\n      <button type=\"button\" class=\"user-guide-panel-close\" aria-label=\"Close\" (click)=\"exit()\">\n        <svg class=\"svg-icon-close\" xmlns=\"http://www.w3.org/2000/svg\" width=\"10px\" height=\"10px\" viewBox=\"0 0 12 12\" version=\"1.1\">\n          <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n            <g transform=\"translate(-2.000000, -2.000000)\" fill-rule=\"nonzero\">\n              <polygon\n                [style.fill]=\"extraConfig?.operationColor\"\n                points=\"8 6.58578644 12.2426407 2.34314575 13.6568542 3.75735931 9.41421356 8 13.6568542 12.2426407 12.2426407 13.6568542 8 9.41421356 3.75735931 13.6568542 2.34314575 12.2426407 6.58578644 8 2.34314575 3.75735931 3.75735931 2.34314575\"\n              />\n            </g>\n          </g>\n        </svg>\n      </button>\n    </div>\n    <div class=\"user-guide-panel-multiple-body\" [style.maxWidth.px]=\"maxContentWidth\">\n      <div class=\"user-guide-panel-title\" [style.color]=\"extraConfig?.infoColor\">{{ title }}</div>\n      <div *ngIf=\"content\" class=\"user-guide-panel-content\" [style.color]=\"extraConfig?.infoColor\">\n        <div *ngIf=\"!isTemplateContent()\" [innerHTML]=\"content | safe : 'html'\"></div>\n        <ng-container *ngIf=\"isTemplateContent()\">\n          <ng-container *ngTemplateOutlet=\"contentTemplate\"></ng-container>\n        </ng-container>\n      </div>\n      <div *ngIf=\"showOperateZone\" class=\"operate-zone\">\n        <p><i class=\"icon icon-info-o\" style=\"color: rgb(81, 112, 255); padding-right: 4px\"></i>{{ i18nCommonText.autoFill }}</p>\n      </div>\n    </div>\n    <div class=\"user-guide-panel-multiple-footer\" [class.user-guide-panel-multiple-footer-only-dot]=\"!showButtons\">\n      <div class=\"user-guide-panel-multiple-footer-left\">\n        <ul class=\"devui-carousel-dots\" *ngIf=\"stepsLength > 1 && showDots\">\n          <li\n            class=\"dot-item\"\n            [ngClass]=\"{ active: currentStep === index }\"\n            [style.background]=\"currentStep === index ? extraConfig?.operationColor : extraConfig?.dotColor\"\n            *ngFor=\"let item of items; let index = index\"\n            (click)=\"switchStep(index)\"\n          ></li>\n        </ul>\n      </div>\n      <div *ngIf=\"showButtons\" class=\"user-guide-panel-multiple-footer-right\">\n        <d-button bsStyle=\"common\" [disabled]=\"!canPrev\" *ngIf=\"showPrevButton\" (btnClick)=\"prev()\">{{ i18nCommonText.prev }}</d-button>\n        <d-button *ngIf=\"!canFinish\" [disabled]=\"!canNext\" [bsStyle]=\"nextButtonType\" (btnClick)=\"next()\">{{\n          i18nCommonText.next\n        }}</d-button>\n        <d-button\n          *ngIf=\"currentStep === stepsLength - 1 && canFinish\"\n          [bsStyle]=\"nextButtonType\"\n          [disabled]=\"!canFinish\"\n          (btnClick)=\"exit()\"\n          >{{ i18nCommonText.finish }}</d-button\n        >\n      </div>\n    </div>\n  </div>\n\n  <div *ngIf=\"stepsLength === 1 && curStepType === 'tip'\">\n    <div *ngIf=\"curStepType === 'tip'\" class=\"devui-user-guide-panel-arrow\"></div>\n    <div [class.user-guide-panel-tip]=\"curStepType === 'tip'\" [class.user-guide-panel-single]=\"curStepType !== 'tip'\">\n      {{ title }}\n      <div *ngIf=\"content\" class=\"user-guide-panel-content\" [innerHTML]=\"content | safe : 'html'\"></div>\n      <button type=\"button\" class=\"close\" aria-label=\"Close\" (click)=\"exit()\">\n        <svg class=\"svg-icon-close\" xmlns=\"http://www.w3.org/2000/svg\" width=\"10px\" height=\"10px\" viewBox=\"0 0 12 12\" version=\"1.1\">\n          <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n            <g transform=\"translate(-2.000000, -2.000000)\" fill-rule=\"nonzero\">\n              <polygon\n                points=\"8 6.58578644 12.2426407 2.34314575 13.6568542 3.75735931 9.41421356 8 13.6568542 12.2426407 12.2426407 13.6568542 8 9.41421356 3.75735931 13.6568542 2.34314575 12.2426407 6.58578644 8 2.34314575 3.75735931 3.75735931 2.34314575\"\n              />\n            </g>\n          </g>\n        </svg>\n      </button>\n    </div>\n  </div>\n</div>\n", styles: [".devui-font-size-base{font-size:12px;font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:12px;font-size:var(--devui-font-size, 12px);font-weight:400;line-height:1.5}.devui-font-size-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px);font-weight:700;line-height:1.5}.devui-font-size-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px);font-weight:700;line-height:1.5}.devui-font-size-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px);font-weight:700;line-height:1.5}.user-guide-mask-layer{position:fixed;z-index:1079;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) - 1);inset:0;background:#000000;opacity:.28;display:none}.show-overlay{display:block!important}.user-guide-normal-overlay{position:fixed;z-index:1079;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) - 1);inset:0;display:none}.user-guide-top-overlay{top:0;left:0;position:absolute;width:100%;z-index:10000;background:#000000;opacity:.28;display:none;transition:all .3s ease-out}.user-guide-bottom-overlay{left:0;position:absolute;width:100%;z-index:1080;z-index:var(--devui-z-index-full-page-overlay, 1080);background:#000000;opacity:.28;display:none;transition:all .3s ease-out}.user-guide-left-overlay{left:0;position:absolute;z-index:1080;z-index:var(--devui-z-index-full-page-overlay, 1080);background:#000000;opacity:.28;display:none;transition:all .3s ease-out}.user-guide-right-overlay{position:absolute;z-index:1080;z-index:var(--devui-z-index-full-page-overlay, 1080);background:#000000;opacity:.28;display:none;transition:all .3s ease-out}.user-guide-top-border,.user-guide-bottom-border,.user-guide-left-border,.user-guide-right-border{position:absolute;z-index:1081;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) + 1);background-color:#5e7ce0;background-color:var(--devui-brand, #5e7ce0);border:1px solid #ffffff;border:1px solid var(--devui-base-bg, #ffffff);transition:all .3s ease-out;display:none}.user-guide-dot{position:absolute;z-index:1081;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) + 1);width:32px;height:32px;animation:2s ease 0s infinite normal both ops-animation;display:none}.user-guide-panel{position:absolute;z-index:10001;transition:all .3s ease-out}.user-guide-panel-multiple{min-width:400px;padding:12px 20px;background-color:#fff;background-color:var(--devui-connected-overlay-bg, #ffffff);transition:all .3s ease-out;border-radius:2px;border-radius:var(--devui-border-radius, 2px);box-shadow:0 4px 16px #00000047}.user-guide-panel-multiple-header{padding:8px 32px 0}.user-guide-panel-multiple-body{max-width:320px;font-size:14px;font-size:var(--devui-font-size-card-title, 14px)}.user-guide-panel-multiple-body .finish-icon{position:absolute;top:50px;right:8px}.user-guide-panel-multiple-footer{margin-top:16px;display:flex;justify-content:space-between;align-items:center}.user-guide-panel-multiple-footer d-button{margin:4px}.user-guide-panel-multiple-footer-only-dot{margin-top:8px;justify-content:flex-end}.user-guide-panel-single{background-color:#fff;background-color:var(--devui-connected-overlay-bg, #ffffff);padding:8px 12px;transition:all .3s ease-out;border-radius:2px;border-radius:var(--devui-border-radius, 2px);box-shadow:0 4px 16px #00000047}.user-guide-panel-single button.close{margin-left:12px;font-size:16px;font-size:var(--devui-font-size-icon, 16px);font-weight:700;line-height:1;color:#71757f;color:var(--devui-icon-fill, #71757f);cursor:pointer;background:transparent;border:0;-webkit-appearance:none}.user-guide-panel-single button.close svg.svg-icon-close polygon{fill:#575d6c;fill:var(--devui-text-weak, #575d6c)}.user-guide-panel-tip{background-color:#5e7ce0;background-color:var(--devui-brand, #5e7ce0);padding:8px 12px;transition:all .3s ease-out;border-radius:2px;border-radius:var(--devui-border-radius, 2px);box-shadow:0 4px 16px #00000047;color:#fff;color:var(--devui-light-text, #ffffff)}.user-guide-panel-tip button.close{margin-left:12px;font-size:16px;font-size:var(--devui-font-size-icon, 16px);font-weight:700;line-height:1;color:#fff;color:var(--devui-light-text, #ffffff);cursor:pointer;background:transparent;border:0;-webkit-appearance:none}.user-guide-panel-tip button.close svg.svg-icon-close polygon{fill:#fff;fill:var(--devui-light-text, #ffffff)}.user-guide-panel-close{position:absolute;right:16px;top:16px;font-size:16px;font-size:var(--devui-font-size-icon, 16px);font-weight:700;line-height:1;color:#71757f;color:var(--devui-icon-fill, #71757f);cursor:pointer;background:transparent;border:0;-webkit-appearance:none}.user-guide-panel-close svg.svg-icon-close polygon{fill:#575d6c;fill:var(--devui-text-weak, #575d6c)}.user-guide-panel-close:hover svg.svg-icon-close polygon{fill:#252b3a;fill:var(--devui-icon-fill-active, #252b3a)}.user-guide-panel-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px);color:#252b3a;color:var(--devui-text, #252b3a)}.user-guide-panel-content{margin-top:8px;font-size:12px;font-size:var(--devui-font-size, 12px);color:#71757f;color:var(--devui-aide-text, #71757f)}.devui-carousel-dots{display:flex;flex-wrap:wrap}.devui-carousel-dots .dot-item{width:6px;height:6px;border-radius:3px;margin-right:8px;margin-bottom:4px;background:#71757f;background:var(--devui-icon-fill, #71757f)}.devui-carousel-dots .dot-item:hover{cursor:pointer;background:#5e7ce0;background:var(--devui-brand, #5e7ce0)}.devui-carousel-dots .dot-item.active{background:#5e7ce0;background:var(--devui-brand, #5e7ce0);transition:all .5s ease}.devui-user-guide-panel-arrow{width:8px;height:8px;transform:rotate(45deg);display:block;z-index:-1;background-color:#5e7ce0;background-color:var(--devui-brand, #5e7ce0);position:relative}.devui-mask-layer{inset:0;position:\"fixed\";z-index:1079;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) - 1)}.devui-carousel-wapper{display:inline-block}.operate-zone{margin-top:8px;padding:8px 0;border:2px dashed #d7d8da;border:2px dashed var(--devui-line, #d7d8da);text-align:center;cursor:pointer}.emphasize-animation{animation:1s ease 0s infinite normal both ops-animation}.emphasize-top-animation{animation:1.5s cubic-bezier(.645,.045,.355,1) 0s infinite normal both breath-top-animation;animation:1.5s var(--devui-animation-ease-in-smooth, cubic-bezier(.645, .045, .355, 1)) 0s infinite normal both breath-top-animation}.emphasize-bottom-animation{animation:1.5s cubic-bezier(.645,.045,.355,1) 0s infinite normal both breath-bottom-animation;animation:1.5s var(--devui-animation-ease-in-smooth, cubic-bezier(.645, .045, .355, 1)) 0s infinite normal both breath-bottom-animation}.emphasize-left-animation{animation:1.5s cubic-bezier(.645,.045,.355,1) 0s infinite normal both breath-left-animation;animation:1.5s var(--devui-animation-ease-in-smooth, cubic-bezier(.645, .045, .355, 1)) 0s infinite normal both breath-left-animation}.emphasize-right-animation{animation:1.5s cubic-bezier(.645,.045,.355,1) 0s infinite normal both breath-right-animation;animation:1.5s var(--devui-animation-ease-in-smooth, cubic-bezier(.645, .045, .355, 1)) 0s infinite normal both breath-right-animation}@keyframes ops-animation{0%{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}60%{box-shadow:0 1px 4px #5e7ce0;box-shadow:0 1px 4px var(--devui-brand, #5e7ce0)}to{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}}@keyframes breath-top-animation{0%{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}60%{box-shadow:0 -3px 4px #5e7ce0;box-shadow:0 -3px 4px var(--devui-brand, #5e7ce0)}to{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}}@keyframes breath-bottom-animation{0%{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}60%{box-shadow:0 3px 4px #5e7ce0;box-shadow:0 3px 4px var(--devui-brand, #5e7ce0)}to{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}}@keyframes breath-left-animation{0%{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}60%{box-shadow:-3px 0 4px #5e7ce0;box-shadow:-3px 0 4px var(--devui-brand, #5e7ce0)}to{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}}@keyframes breath-right-animation{0%{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}60%{box-shadow:3px 0 4px #5e7ce0;box-shadow:3px 0 4px var(--devui-brand, #5e7ce0)}to{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}}\n"], dependencies: [{ kind: "directive", type: i3.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i3.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i3.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i4.ButtonComponent, selector: "d-button", inputs: ["id", "type", "bsStyle", "shape", "bsSize", "bsPosition", "bordered", "icon", "disabled", "showLoading", "width", "autofocus", "loadingTemplateRef"], outputs: ["btnClick"] }, { kind: "pipe", type: i5.SafePipe, name: "safe" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideUIComponent, decorators: [{
            type: Component,
            args: [{ selector: 'd-user-guide-ui', template: "<div [class.show-overlay]=\"showMaskLayer && isCover\" class=\"user-guide-mask-layer\"></div>\n<div [class.show-overlay]=\"showNormalOverlay && isCover\" class=\"user-guide-normal-overlay\"></div>\n\n<div [class.show-overlay]=\"showTopOverlay && isCover\" class=\"user-guide-top-overlay\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showBottomOverlay && isCover\" class=\"user-guide-bottom-overlay\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showLeftOverlay && isCover\" class=\"user-guide-left-overlay\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showRightOverlay && isCover\" class=\"user-guide-right-overlay\" (click)=\"disableClick($event)\"></div>\n\n<div [class.show-overlay]=\"showBorder && isCover\" class=\"user-guide-top-border\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showBorder && isCover\" class=\"user-guide-bottom-border\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showBorder && isCover\" class=\"user-guide-left-border\" (click)=\"disableClick($event)\"></div>\n<div [class.show-overlay]=\"showBorder && isCover\" class=\"user-guide-right-border\" (click)=\"disableClick($event)\"></div>\n\n<div class=\"user-guide-panel\">\n  <div\n    *ngIf=\"!isCover && (stepsLength !== 1 || curStepType !== 'tip') && curStepType !== 'display'\"\n    class=\"devui-user-guide-panel-arrow\"\n    [style.background-color]=\"extraConfig?.panelBackground\"\n  ></div>\n  <div\n    *ngIf=\"stepsLength !== 1 || curStepType !== 'tip'\"\n    id=\"devui-user-guide\"\n    class=\"user-guide-panel-multiple\"\n    [style.background]=\"extraConfig?.panelBackground\"\n  >\n    <div class=\"user-guide-panel-multiple-header\">\n      <button type=\"button\" class=\"user-guide-panel-close\" aria-label=\"Close\" (click)=\"exit()\">\n        <svg class=\"svg-icon-close\" xmlns=\"http://www.w3.org/2000/svg\" width=\"10px\" height=\"10px\" viewBox=\"0 0 12 12\" version=\"1.1\">\n          <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n            <g transform=\"translate(-2.000000, -2.000000)\" fill-rule=\"nonzero\">\n              <polygon\n                [style.fill]=\"extraConfig?.operationColor\"\n                points=\"8 6.58578644 12.2426407 2.34314575 13.6568542 3.75735931 9.41421356 8 13.6568542 12.2426407 12.2426407 13.6568542 8 9.41421356 3.75735931 13.6568542 2.34314575 12.2426407 6.58578644 8 2.34314575 3.75735931 3.75735931 2.34314575\"\n              />\n            </g>\n          </g>\n        </svg>\n      </button>\n    </div>\n    <div class=\"user-guide-panel-multiple-body\" [style.maxWidth.px]=\"maxContentWidth\">\n      <div class=\"user-guide-panel-title\" [style.color]=\"extraConfig?.infoColor\">{{ title }}</div>\n      <div *ngIf=\"content\" class=\"user-guide-panel-content\" [style.color]=\"extraConfig?.infoColor\">\n        <div *ngIf=\"!isTemplateContent()\" [innerHTML]=\"content | safe : 'html'\"></div>\n        <ng-container *ngIf=\"isTemplateContent()\">\n          <ng-container *ngTemplateOutlet=\"contentTemplate\"></ng-container>\n        </ng-container>\n      </div>\n      <div *ngIf=\"showOperateZone\" class=\"operate-zone\">\n        <p><i class=\"icon icon-info-o\" style=\"color: rgb(81, 112, 255); padding-right: 4px\"></i>{{ i18nCommonText.autoFill }}</p>\n      </div>\n    </div>\n    <div class=\"user-guide-panel-multiple-footer\" [class.user-guide-panel-multiple-footer-only-dot]=\"!showButtons\">\n      <div class=\"user-guide-panel-multiple-footer-left\">\n        <ul class=\"devui-carousel-dots\" *ngIf=\"stepsLength > 1 && showDots\">\n          <li\n            class=\"dot-item\"\n            [ngClass]=\"{ active: currentStep === index }\"\n            [style.background]=\"currentStep === index ? extraConfig?.operationColor : extraConfig?.dotColor\"\n            *ngFor=\"let item of items; let index = index\"\n            (click)=\"switchStep(index)\"\n          ></li>\n        </ul>\n      </div>\n      <div *ngIf=\"showButtons\" class=\"user-guide-panel-multiple-footer-right\">\n        <d-button bsStyle=\"common\" [disabled]=\"!canPrev\" *ngIf=\"showPrevButton\" (btnClick)=\"prev()\">{{ i18nCommonText.prev }}</d-button>\n        <d-button *ngIf=\"!canFinish\" [disabled]=\"!canNext\" [bsStyle]=\"nextButtonType\" (btnClick)=\"next()\">{{\n          i18nCommonText.next\n        }}</d-button>\n        <d-button\n          *ngIf=\"currentStep === stepsLength - 1 && canFinish\"\n          [bsStyle]=\"nextButtonType\"\n          [disabled]=\"!canFinish\"\n          (btnClick)=\"exit()\"\n          >{{ i18nCommonText.finish }}</d-button\n        >\n      </div>\n    </div>\n  </div>\n\n  <div *ngIf=\"stepsLength === 1 && curStepType === 'tip'\">\n    <div *ngIf=\"curStepType === 'tip'\" class=\"devui-user-guide-panel-arrow\"></div>\n    <div [class.user-guide-panel-tip]=\"curStepType === 'tip'\" [class.user-guide-panel-single]=\"curStepType !== 'tip'\">\n      {{ title }}\n      <div *ngIf=\"content\" class=\"user-guide-panel-content\" [innerHTML]=\"content | safe : 'html'\"></div>\n      <button type=\"button\" class=\"close\" aria-label=\"Close\" (click)=\"exit()\">\n        <svg class=\"svg-icon-close\" xmlns=\"http://www.w3.org/2000/svg\" width=\"10px\" height=\"10px\" viewBox=\"0 0 12 12\" version=\"1.1\">\n          <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n            <g transform=\"translate(-2.000000, -2.000000)\" fill-rule=\"nonzero\">\n              <polygon\n                points=\"8 6.58578644 12.2426407 2.34314575 13.6568542 3.75735931 9.41421356 8 13.6568542 12.2426407 12.2426407 13.6568542 8 9.41421356 3.75735931 13.6568542 2.34314575 12.2426407 6.58578644 8 2.34314575 3.75735931 3.75735931 2.34314575\"\n              />\n            </g>\n          </g>\n        </svg>\n      </button>\n    </div>\n  </div>\n</div>\n", styles: [".devui-font-size-base{font-size:12px;font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:12px;font-size:var(--devui-font-size, 12px);font-weight:400;line-height:1.5}.devui-font-size-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px);font-weight:700;line-height:1.5}.devui-font-size-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px);font-weight:700;line-height:1.5}.devui-font-size-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px);font-weight:700;line-height:1.5}.user-guide-mask-layer{position:fixed;z-index:1079;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) - 1);inset:0;background:#000000;opacity:.28;display:none}.show-overlay{display:block!important}.user-guide-normal-overlay{position:fixed;z-index:1079;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) - 1);inset:0;display:none}.user-guide-top-overlay{top:0;left:0;position:absolute;width:100%;z-index:10000;background:#000000;opacity:.28;display:none;transition:all .3s ease-out}.user-guide-bottom-overlay{left:0;position:absolute;width:100%;z-index:1080;z-index:var(--devui-z-index-full-page-overlay, 1080);background:#000000;opacity:.28;display:none;transition:all .3s ease-out}.user-guide-left-overlay{left:0;position:absolute;z-index:1080;z-index:var(--devui-z-index-full-page-overlay, 1080);background:#000000;opacity:.28;display:none;transition:all .3s ease-out}.user-guide-right-overlay{position:absolute;z-index:1080;z-index:var(--devui-z-index-full-page-overlay, 1080);background:#000000;opacity:.28;display:none;transition:all .3s ease-out}.user-guide-top-border,.user-guide-bottom-border,.user-guide-left-border,.user-guide-right-border{position:absolute;z-index:1081;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) + 1);background-color:#5e7ce0;background-color:var(--devui-brand, #5e7ce0);border:1px solid #ffffff;border:1px solid var(--devui-base-bg, #ffffff);transition:all .3s ease-out;display:none}.user-guide-dot{position:absolute;z-index:1081;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) + 1);width:32px;height:32px;animation:2s ease 0s infinite normal both ops-animation;display:none}.user-guide-panel{position:absolute;z-index:10001;transition:all .3s ease-out}.user-guide-panel-multiple{min-width:400px;padding:12px 20px;background-color:#fff;background-color:var(--devui-connected-overlay-bg, #ffffff);transition:all .3s ease-out;border-radius:2px;border-radius:var(--devui-border-radius, 2px);box-shadow:0 4px 16px #00000047}.user-guide-panel-multiple-header{padding:8px 32px 0}.user-guide-panel-multiple-body{max-width:320px;font-size:14px;font-size:var(--devui-font-size-card-title, 14px)}.user-guide-panel-multiple-body .finish-icon{position:absolute;top:50px;right:8px}.user-guide-panel-multiple-footer{margin-top:16px;display:flex;justify-content:space-between;align-items:center}.user-guide-panel-multiple-footer d-button{margin:4px}.user-guide-panel-multiple-footer-only-dot{margin-top:8px;justify-content:flex-end}.user-guide-panel-single{background-color:#fff;background-color:var(--devui-connected-overlay-bg, #ffffff);padding:8px 12px;transition:all .3s ease-out;border-radius:2px;border-radius:var(--devui-border-radius, 2px);box-shadow:0 4px 16px #00000047}.user-guide-panel-single button.close{margin-left:12px;font-size:16px;font-size:var(--devui-font-size-icon, 16px);font-weight:700;line-height:1;color:#71757f;color:var(--devui-icon-fill, #71757f);cursor:pointer;background:transparent;border:0;-webkit-appearance:none}.user-guide-panel-single button.close svg.svg-icon-close polygon{fill:#575d6c;fill:var(--devui-text-weak, #575d6c)}.user-guide-panel-tip{background-color:#5e7ce0;background-color:var(--devui-brand, #5e7ce0);padding:8px 12px;transition:all .3s ease-out;border-radius:2px;border-radius:var(--devui-border-radius, 2px);box-shadow:0 4px 16px #00000047;color:#fff;color:var(--devui-light-text, #ffffff)}.user-guide-panel-tip button.close{margin-left:12px;font-size:16px;font-size:var(--devui-font-size-icon, 16px);font-weight:700;line-height:1;color:#fff;color:var(--devui-light-text, #ffffff);cursor:pointer;background:transparent;border:0;-webkit-appearance:none}.user-guide-panel-tip button.close svg.svg-icon-close polygon{fill:#fff;fill:var(--devui-light-text, #ffffff)}.user-guide-panel-close{position:absolute;right:16px;top:16px;font-size:16px;font-size:var(--devui-font-size-icon, 16px);font-weight:700;line-height:1;color:#71757f;color:var(--devui-icon-fill, #71757f);cursor:pointer;background:transparent;border:0;-webkit-appearance:none}.user-guide-panel-close svg.svg-icon-close polygon{fill:#575d6c;fill:var(--devui-text-weak, #575d6c)}.user-guide-panel-close:hover svg.svg-icon-close polygon{fill:#252b3a;fill:var(--devui-icon-fill-active, #252b3a)}.user-guide-panel-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px);color:#252b3a;color:var(--devui-text, #252b3a)}.user-guide-panel-content{margin-top:8px;font-size:12px;font-size:var(--devui-font-size, 12px);color:#71757f;color:var(--devui-aide-text, #71757f)}.devui-carousel-dots{display:flex;flex-wrap:wrap}.devui-carousel-dots .dot-item{width:6px;height:6px;border-radius:3px;margin-right:8px;margin-bottom:4px;background:#71757f;background:var(--devui-icon-fill, #71757f)}.devui-carousel-dots .dot-item:hover{cursor:pointer;background:#5e7ce0;background:var(--devui-brand, #5e7ce0)}.devui-carousel-dots .dot-item.active{background:#5e7ce0;background:var(--devui-brand, #5e7ce0);transition:all .5s ease}.devui-user-guide-panel-arrow{width:8px;height:8px;transform:rotate(45deg);display:block;z-index:-1;background-color:#5e7ce0;background-color:var(--devui-brand, #5e7ce0);position:relative}.devui-mask-layer{inset:0;position:\"fixed\";z-index:1079;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) - 1)}.devui-carousel-wapper{display:inline-block}.operate-zone{margin-top:8px;padding:8px 0;border:2px dashed #d7d8da;border:2px dashed var(--devui-line, #d7d8da);text-align:center;cursor:pointer}.emphasize-animation{animation:1s ease 0s infinite normal both ops-animation}.emphasize-top-animation{animation:1.5s cubic-bezier(.645,.045,.355,1) 0s infinite normal both breath-top-animation;animation:1.5s var(--devui-animation-ease-in-smooth, cubic-bezier(.645, .045, .355, 1)) 0s infinite normal both breath-top-animation}.emphasize-bottom-animation{animation:1.5s cubic-bezier(.645,.045,.355,1) 0s infinite normal both breath-bottom-animation;animation:1.5s var(--devui-animation-ease-in-smooth, cubic-bezier(.645, .045, .355, 1)) 0s infinite normal both breath-bottom-animation}.emphasize-left-animation{animation:1.5s cubic-bezier(.645,.045,.355,1) 0s infinite normal both breath-left-animation;animation:1.5s var(--devui-animation-ease-in-smooth, cubic-bezier(.645, .045, .355, 1)) 0s infinite normal both breath-left-animation}.emphasize-right-animation{animation:1.5s cubic-bezier(.645,.045,.355,1) 0s infinite normal both breath-right-animation;animation:1.5s var(--devui-animation-ease-in-smooth, cubic-bezier(.645, .045, .355, 1)) 0s infinite normal both breath-right-animation}@keyframes ops-animation{0%{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}60%{box-shadow:0 1px 4px #5e7ce0;box-shadow:0 1px 4px var(--devui-brand, #5e7ce0)}to{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}}@keyframes breath-top-animation{0%{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}60%{box-shadow:0 -3px 4px #5e7ce0;box-shadow:0 -3px 4px var(--devui-brand, #5e7ce0)}to{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}}@keyframes breath-bottom-animation{0%{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}60%{box-shadow:0 3px 4px #5e7ce0;box-shadow:0 3px 4px var(--devui-brand, #5e7ce0)}to{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}}@keyframes breath-left-animation{0%{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}60%{box-shadow:-3px 0 4px #5e7ce0;box-shadow:-3px 0 4px var(--devui-brand, #5e7ce0)}to{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}}@keyframes breath-right-animation{0%{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}60%{box-shadow:3px 0 4px #5e7ce0;box-shadow:3px 0 4px var(--devui-brand, #5e7ce0)}to{box-shadow:0 0 #5e7ce0;box-shadow:0 0 0 var(--devui-brand, #5e7ce0)}}\n"] }]
        }], ctorParameters: function () { return [{ type: UserGuideCoreService }, { type: i2.I18nService }]; }, propDecorators: { showDots: [{
                type: Input
            }], maxContentWidth: [{
                type: Input
            }], isCover: [{
                type: Input
            }], extraConfig: [{
                type: Input
            }] } });

class UserGuideComponent {
    constructor(componentFactoryResolver, overlayContainerRef, userGuideCoreService, i18n) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.overlayContainerRef = overlayContainerRef;
        this.userGuideCoreService = userGuideCoreService;
        this.i18n = i18n;
        this.userGuideEntrancePosition = { bottom: '30px', left: '30px' };
        this.showUserGuideEntrance = true;
    }
    ngOnInit() {
        this.firstOpenShow = localStorage.getItem('devui-user-guide-first-open-show') || 'true';
        this.i18nCommonText = this.i18n.getI18nText().userGuide;
        this.i18nSubscription = this.i18n.langChange().subscribe((data) => {
            this.i18nCommonText = data.userGuide;
        });
    }
    ngAfterViewInit() {
        setTimeout(() => {
            var _a;
            for (let i = 0; i < this.steps.length; i++) {
                if (((_a = this.steps[i]) === null || _a === void 0 ? void 0 : _a.defaultStart) === true && this.firstOpenShow === 'true') {
                    this.start(i);
                    localStorage.setItem('devui-user-guide-first-open-show', 'false');
                    break;
                }
            }
        }, 0);
    }
    ngOnDestroy() {
        if (this.i18nSubscription) {
            this.i18nSubscription.unsubscribe();
        }
    }
    start(index) {
        this.userGuideCoreService.setSteps(this.steps[index].detail);
        if (this.steps[index].onExit) {
            this.userGuideCoreService.setExitFunction(this.steps[index].onExit);
        }
        this.userGuideCoreService.isFinished.subscribe((item) => {
            this.steps[index].isFinished = item;
            if (item === true) {
                if (this.modalRef) {
                    this.modalRef.hostView.destroy();
                }
            }
        });
        this.userGuideCoreService.start();
        this.createGuide(index);
        this.userGuideCoreService.next();
        this.currentTutorial = index;
        localStorage.setItem('devui-user-guide-last-tutorial', index.toString());
    }
    goStep(index) {
        let realStep = index;
        for (let i = 0; i < index; i++) {
            if (this.steps[this.currentTutorial].detail[i].type === 'interactable'
                && this.steps[this.currentTutorial].detail[i].eventType === 'clickable') {
                realStep = i;
                break;
            }
        }
        this.userGuideCoreService.goStep(realStep);
    }
    createGuide(index) {
        var _a, _b, _c, _d, _e, _f;
        this.modalRef = this.overlayContainerRef.createComponent(this.componentFactoryResolver.resolveComponentFactory(UserGuideUIComponent));
        this.modalRef.instance.showDots = (_a = this.steps[index]) === null || _a === void 0 ? void 0 : _a.showDots;
        this.modalRef.instance.maxContentWidth = ((_b = this.steps[index]) === null || _b === void 0 ? void 0 : _b.maxContentWidth) ? (_c = this.steps[index]) === null || _c === void 0 ? void 0 : _c.maxContentWidth : 320;
        this.modalRef.instance.isCover = ((_d = this.steps[index]) === null || _d === void 0 ? void 0 : _d.isCover) === undefined ? true : (_e = this.steps[index]) === null || _e === void 0 ? void 0 : _e.isCover;
        this.modalRef.instance.extraConfig = (_f = this.steps[index]) === null || _f === void 0 ? void 0 : _f.extraConfig;
        this.modalRef.instance.close = () => {
            if (this.modalRef) {
                this.modalRef.hostView.destroy();
            }
        };
        const panel = document.querySelector('.user-guide-panel');
        panel.style.visibility = 'hidden';
    }
}
UserGuideComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideComponent, deps: [{ token: i0.ComponentFactoryResolver }, { token: i1.OverlayContainerRef }, { token: UserGuideCoreService }, { token: i2.I18nService }], target: i0.ɵɵFactoryTarget.Component });
UserGuideComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.1.5", type: UserGuideComponent, selector: "d-user-guide", inputs: { steps: "steps", userGuideEntrancePosition: "userGuideEntrancePosition", showUserGuideEntrance: "showUserGuideEntrance" }, ngImport: i0, template: "<div class=\"user-guide-wapper\" dDropDown appendToBody>\n  <div\n    dDropDownToggle\n    class=\"user-guide\"\n    [style.bottom]=\"userGuideEntrancePosition.bottom\"\n    [style.left]=\"userGuideEntrancePosition.left\"\n    [class.user-guide-hidden]=\"showUserGuideEntrance === false\"\n  >\n    <div class=\"user-guide-text\">{{ i18nCommonText.guide }}</div>\n  </div>\n  <div dDropDownMenu class=\"user-guide-window\">\n    <ul>\n      <li *ngFor=\"let step of steps; let i = index\" role=\"menuitem\" class=\"devui-dropdown-item\" (click)=\"start(i)\">\n        <div class=\"step\">\n          <div class=\"left-item\">\n            <div class=\"title\">{{ step.title }}</div>\n            <div class=\"desc\">{{ step.desc }}</div>\n          </div>\n          <div class=\"right-item\">\n            <i *ngIf=\"step.isFinished\" class=\"icon icon-right-o\" style=\"color: rgb(61, 204, 166); font-size: 16px\"></i>\n          </div>\n        </div>\n      </li>\n    </ul>\n  </div>\n</div>\n", styles: [".devui-font-size-base{font-size:12px;font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:12px;font-size:var(--devui-font-size, 12px);font-weight:400;line-height:1.5}.devui-font-size-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px);font-weight:700;line-height:1.5}.devui-font-size-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px);font-weight:700;line-height:1.5}.devui-font-size-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px);font-weight:700;line-height:1.5}.user-guide{width:60px;height:60px;border-radius:50%;color:#fff;color:var(--devui-light-text, #ffffff);background-color:#5e7ce0;background-color:var(--devui-brand, #5e7ce0);box-shadow:0 1px 4px #252b3a33;box-shadow:var(--devui-shadow-length-base, 0 1px 4px 0) var(--devui-shadow, rgba(37, 43, 58, .2));position:fixed;z-index:1079;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) - 1)}.user-guide-hidden{visibility:hidden}.user-guide-text{line-height:60px;text-align:center;font-weight:700}.user-guide:hover{cursor:pointer;box-shadow:0 8px 16px #252b3a33;box-shadow:var(--devui-shadow-length-hover, 0 8px 16px 0) var(--devui-shadow, rgba(37, 43, 58, .2))}.user-guide-window{width:200px}.user-guide-window li{padding:8px 12px 8px 20px;cursor:pointer}.user-guide-window li .step{display:flex;justify-content:space-between;align-items:center}.user-guide-window li .title{font-size:12px;font-size:var(--devui-font-size, 12px);font-weight:700}\n"], dependencies: [{ kind: "directive", type: i3.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i5$1.DropDownDirective, selector: "[dDropDown]", inputs: ["isOpen", "disabled", "showAnimation", "trigger", "closeScope", "closeOnMouseLeaveMenu"], outputs: ["toggleEvent"], exportAs: ["d-dropdown"] }, { kind: "directive", type: i5$1.DropDownMenuDirective, selector: "[dDropDownMenu]", exportAs: ["d-dropdown-menu"] }, { kind: "directive", type: i5$1.DropDownToggleDirective, selector: "[dDropDownToggle]", inputs: ["toggleOnFocus", "autoFocus"], exportAs: ["d-dropdown-toggle"] }, { kind: "component", type: i5$1.DropDownAppendToBodyComponent, selector: "[dDropDown][appendToBody]", inputs: ["alignOrigin", "appendToBodyDirections", "appendToBodyScrollStrategy"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideComponent, decorators: [{
            type: Component,
            args: [{ selector: 'd-user-guide', template: "<div class=\"user-guide-wapper\" dDropDown appendToBody>\n  <div\n    dDropDownToggle\n    class=\"user-guide\"\n    [style.bottom]=\"userGuideEntrancePosition.bottom\"\n    [style.left]=\"userGuideEntrancePosition.left\"\n    [class.user-guide-hidden]=\"showUserGuideEntrance === false\"\n  >\n    <div class=\"user-guide-text\">{{ i18nCommonText.guide }}</div>\n  </div>\n  <div dDropDownMenu class=\"user-guide-window\">\n    <ul>\n      <li *ngFor=\"let step of steps; let i = index\" role=\"menuitem\" class=\"devui-dropdown-item\" (click)=\"start(i)\">\n        <div class=\"step\">\n          <div class=\"left-item\">\n            <div class=\"title\">{{ step.title }}</div>\n            <div class=\"desc\">{{ step.desc }}</div>\n          </div>\n          <div class=\"right-item\">\n            <i *ngIf=\"step.isFinished\" class=\"icon icon-right-o\" style=\"color: rgb(61, 204, 166); font-size: 16px\"></i>\n          </div>\n        </div>\n      </li>\n    </ul>\n  </div>\n</div>\n", styles: [".devui-font-size-base{font-size:12px;font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:12px;font-size:var(--devui-font-size, 12px);font-weight:400;line-height:1.5}.devui-font-size-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px);font-weight:700;line-height:1.5}.devui-font-size-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px);font-weight:700;line-height:1.5}.devui-font-size-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px);font-weight:700;line-height:1.5}.user-guide{width:60px;height:60px;border-radius:50%;color:#fff;color:var(--devui-light-text, #ffffff);background-color:#5e7ce0;background-color:var(--devui-brand, #5e7ce0);box-shadow:0 1px 4px #252b3a33;box-shadow:var(--devui-shadow-length-base, 0 1px 4px 0) var(--devui-shadow, rgba(37, 43, 58, .2));position:fixed;z-index:1079;z-index:calc(var(--devui-z-index-full-page-overlay, 1080) - 1)}.user-guide-hidden{visibility:hidden}.user-guide-text{line-height:60px;text-align:center;font-weight:700}.user-guide:hover{cursor:pointer;box-shadow:0 8px 16px #252b3a33;box-shadow:var(--devui-shadow-length-hover, 0 8px 16px 0) var(--devui-shadow, rgba(37, 43, 58, .2))}.user-guide-window{width:200px}.user-guide-window li{padding:8px 12px 8px 20px;cursor:pointer}.user-guide-window li .step{display:flex;justify-content:space-between;align-items:center}.user-guide-window li .title{font-size:12px;font-size:var(--devui-font-size, 12px);font-weight:700}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ComponentFactoryResolver }, { type: i1.OverlayContainerRef }, { type: UserGuideCoreService }, { type: i2.I18nService }]; }, propDecorators: { steps: [{
                type: Input
            }], userGuideEntrancePosition: [{
                type: Input
            }], showUserGuideEntrance: [{
                type: Input
            }] } });

class UserGuideService {
    constructor(componentFactoryResolver, overlayContainerRef, userGuideCoreService) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.overlayContainerRef = overlayContainerRef;
        this.userGuideCoreService = userGuideCoreService;
    }
    setSteps(steps) {
        this.firstOpenShow = localStorage.getItem('devui-user-guide-first-open-show') || 'true';
        this.steps = steps;
        setTimeout(() => {
            var _a;
            for (let i = 0; i < this.steps.length; i++) {
                if (((_a = this.steps[i]) === null || _a === void 0 ? void 0 : _a.defaultStart) === true && this.firstOpenShow === 'true') {
                    this.start(i);
                    localStorage.setItem('devui-user-guide-first-open-show', 'false');
                    break;
                }
            }
        }, 0);
    }
    start(index) {
        this.userGuideCoreService.setSteps(this.steps[index].detail);
        if (this.steps[index].onExit) {
            this.userGuideCoreService.setExitFunction(this.steps[index].onExit);
        }
        this.userGuideCoreService.isFinished.subscribe((item) => {
            this.steps[index].isFinished = item;
            if (item === true) {
                if (this.modalRef) {
                    this.modalRef.hostView.destroy();
                }
            }
        });
        this.userGuideCoreService.start();
        this.createGuide(index);
        this.userGuideCoreService.next();
        this.currentTutorial = index;
        localStorage.setItem('devui-user-guide-last-tutorial', index.toString());
    }
    goStep(index) {
        let realStep = index;
        for (let i = 0; i < index; i++) {
            if (this.steps[this.currentTutorial].detail[i].type === 'interactable'
                && this.steps[this.currentTutorial].detail[i].eventType === 'clickable') {
                realStep = i;
                break;
            }
        }
        this.userGuideCoreService.goStep(realStep);
    }
    createGuide(index) {
        var _a, _b, _c, _d, _e, _f;
        this.modalRef = this.overlayContainerRef.createComponent(this.componentFactoryResolver.resolveComponentFactory(UserGuideUIComponent));
        this.modalRef.instance.showDots = (_a = this.steps[index]) === null || _a === void 0 ? void 0 : _a.showDots;
        this.modalRef.instance.maxContentWidth = ((_b = this.steps[index]) === null || _b === void 0 ? void 0 : _b.maxContentWidth) ? (_c = this.steps[index]) === null || _c === void 0 ? void 0 : _c.maxContentWidth : 320;
        this.modalRef.instance.isCover = ((_d = this.steps[index]) === null || _d === void 0 ? void 0 : _d.isCover) === undefined ? true : (_e = this.steps[index]) === null || _e === void 0 ? void 0 : _e.isCover;
        this.modalRef.instance.extraConfig = (_f = this.steps[index]) === null || _f === void 0 ? void 0 : _f.extraConfig;
        this.modalRef.instance.close = () => {
            if (this.modalRef) {
                this.modalRef.hostView.destroy();
            }
        };
        const panel = document.querySelector('.user-guide-panel');
        panel.style.visibility = 'hidden';
    }
    showDot(item) {
        const dotAttachElement = document.getElementById(item) || document.querySelector(item);
        const dot = document.createElement('span');
        dot.className = 'devui-userguide-dot';
        dot.style.cssText = `
      width: 6px;
      height: 6px;
      border-radius: 100%;
      position: absolute;
      top: 0;
      right: 0;
      transform: translate(50%,-50%);
      background: var(--devui-brand);
    `;
        dotAttachElement.append(dot);
    }
    removeDot() {
        const dot = document.querySelector('.devui-userguide-dot');
        dot.remove();
    }
    updateCurrentStepElement() {
        this.userGuideCoreService.updateCurrentStepElement();
    }
    getCurrentStep() {
        return this.userGuideCoreService.getCurrentStep();
    }
    getCurrentDirection() {
        return this.userGuideCoreService.getCurrentDirection();
    }
    exit() {
        this.userGuideCoreService.exit();
        if (this.modalRef) {
            this.modalRef.instance.close();
        }
    }
}
UserGuideService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideService, deps: [{ token: i0.ComponentFactoryResolver }, { token: i1.OverlayContainerRef }, { token: UserGuideCoreService }], target: i0.ɵɵFactoryTarget.Injectable });
UserGuideService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i0.ComponentFactoryResolver }, { type: i1.OverlayContainerRef }, { type: UserGuideCoreService }]; } });

class UserGuideModule {
}
UserGuideModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
UserGuideModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.1.5", ngImport: i0, type: UserGuideModule, declarations: [UserGuideComponent,
        UserGuideUIComponent], imports: [CommonModule,
        ButtonModule,
        DropDownModule,
        SafePipeModule], exports: [UserGuideComponent,
        UserGuideUIComponent] });
UserGuideModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideModule, providers: [
        UserGuideCoreService,
        UserGuideService
    ], imports: [CommonModule,
        ButtonModule,
        DropDownModule,
        SafePipeModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: UserGuideModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        ButtonModule,
                        DropDownModule,
                        SafePipeModule
                    ],
                    exports: [
                        UserGuideComponent,
                        UserGuideUIComponent
                    ],
                    providers: [
                        UserGuideCoreService,
                        UserGuideService
                    ],
                    declarations: [
                        UserGuideComponent,
                        UserGuideUIComponent
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { UserGuideComponent, UserGuideCoreService, UserGuideModule, UserGuideService, UserGuideUIComponent };
//# sourceMappingURL=ng-devui-user-guide.mjs.map
