import * as i0 from '@angular/core';
import { Injectable, InjectionToken, EventEmitter, Component, ChangeDetectionStrategy, Inject, Input, Output, forwardRef, NgModule } from '@angular/core';
import * as i1 from '@angular/router';
import { RouterModule } from '@angular/router';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i3 from 'ng-devui/dropdown';
import { DropDownModule } from 'ng-devui/dropdown';
import * as i4 from 'ng-devui/search';
import { SearchModule } from 'ng-devui/search';

class BreadCrumbService {
    constructor(router) {
        this.router = router;
    }
    // 与原生routerLink表现形式一致，navigateByUrl()可直接传入字符串类型的链接，并将链接解析为routerLink的urlTree的形式
    navigateTo($event, item) {
        // 兼容a标签与不同键的交互形式
        if ($event.button !== 0 || $event.ctrlKey || $event.metaKey || $event.shiftKey) {
            return;
        }
        if (typeof item.target === 'string' && item.target !== '_self') {
            return;
        }
        $event.preventDefault();
        this.router.navigateByUrl(item.link);
    }
}
BreadCrumbService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: BreadCrumbService, deps: [{ token: i1.Router }], target: i0.ɵɵFactoryTarget.Injectable });
BreadCrumbService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: BreadCrumbService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: BreadCrumbService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1.Router }]; } });

const BREADCRUMB = new InjectionToken('BreadCrumbComponent');

class BreadCrumbItemComponent {
    constructor(breadCrumbComponent, breadCrumbService) {
        this.breadCrumbComponent = breadCrumbComponent;
        this.breadCrumbService = breadCrumbService;
        this.showMenu = false;
        this.isSearch = false;
        this.toggleEvent = new EventEmitter();
    }
    ngOnInit() {
        this.menuListDisplay = this.menuList;
    }
    onToggle($event) {
        this.isOpen = $event;
        this.toggleEvent.emit($event);
    }
    searchEvent($event) {
        if (this.menuList) {
            this.menuListDisplay = this.menuList.filter(item => item.name.toLowerCase().includes($event.toLowerCase()));
        }
    }
    navigateTo($event, item) {
        this.breadCrumbService.navigateTo($event, item);
    }
}
BreadCrumbItemComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: BreadCrumbItemComponent, deps: [{ token: BREADCRUMB }, { token: BreadCrumbService }], target: i0.ɵɵFactoryTarget.Component });
BreadCrumbItemComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.1.5", type: BreadCrumbItemComponent, selector: "d-breadcrumb-item", inputs: { showMenu: "showMenu", customMenuTemplate: "customMenuTemplate", menuList: "menuList", isSearch: "isSearch" }, outputs: { toggleEvent: "toggleEvent" }, exportAs: ["dBreadcrumbItem"], ngImport: i0, template: "<ng-container *ngIf=\"showMenu; else breadcrumbContentTpl\">\n  <span\n    class=\"devui-breadcrumb-item-with-menu devui-dropdown-no-border devui-dropdown-origin devui-breadcrumb-dropdown-origin\"\n    dDropDown\n    dDropDownToggle\n    appendToBody\n    trigger=\"hover\"\n    (toggleEvent)=\"onToggle($event)\"\n    [ngClass]=\"{ 'devui-breadcrumb-item-active': isOpen }\"\n  >\n    <ng-template [ngTemplateOutlet]=\"breadcrumbContentTpl\"></ng-template>\n    <i class=\"devui-breadcrumb-down-icon\">\n      <svg\n        width=\"1em\"\n        height=\"1em\"\n        viewBox=\"0 0 16 16\"\n        version=\"1.1\"\n        xmlns=\"http://www.w3.org/2000/svg\"\n        xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n      >\n        <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n          <path\n            d=\"M12.1464466,6.85355339 L8.35355339,10.6464466 C8.15829124,10.8417088 7.84170876,10.8417088 7.64644661,10.6464466 L3.85355339,6.85355339 C3.65829124,6.65829124 3.65829124,6.34170876 3.85355339,6.14644661 C3.94732158,6.05267842 4.07449854,6 4.20710678,6 L11.7928932,6 C12.0690356,6 12.2928932,6.22385763 12.2928932,6.5 C12.2928932,6.63260824 12.2402148,6.7597852 12.1464466,6.85355339 Z\"\n            fill-rule=\"nonzero\"\n          ></path>\n        </g>\n      </svg>\n    </i>\n    <div dDropDownMenu class=\"devui-dropdown-menu\">\n      <ng-template\n        [ngTemplateOutlet]=\"customMenuTemplate ? customMenuTemplate : dropDownMenuTpl\"\n        [ngTemplateOutletContext]=\"{\n          $implicit: this\n        }\"\n      >\n      </ng-template>\n    </div>\n  </span>\n</ng-container>\n\n<ng-template #breadcrumbContentTpl>\n  <span class=\"devui-breadcrumb-item\">\n    <ng-content></ng-content>\n  </span>\n</ng-template>\n\n<ng-template #dropDownMenuTpl>\n  <div *ngIf=\"isSearch\" class=\"devui-search-container\">\n    <d-search [size]=\"'sm'\" (searchFn)=\"searchEvent($event)\" [cssClass]=\"'devui-search-in-dropdown'\"></d-search>\n  </div>\n  <ul class=\"devui-breadcrumb-dropdown-menu\">\n    <li *ngFor=\"let item of menuListDisplay\" title=\"{{ item.name }}\">\n      <a\n        *ngIf=\"!item.linkType || item.linkType === 'hrefLink'\"\n        [href]=\"item.link\"\n        rel=\"noopener\"\n        [target]=\"item.target ? item.target : '_self'\"\n        >{{ item.name }}</a\n      >\n      <a\n        *ngIf=\"item.linkType === 'routerLink'\"\n        rel=\"noopener\"\n        [target]=\"item.target\"\n        [href]=\"item.link\"\n        (click)=\"navigateTo($event, item)\"\n        >{{ item.name }}</a\n      >\n    </li>\n  </ul>\n</ng-template>\n\n<span class=\"devui-breadcrumb-separator\">\n  <ng-template\n    [ngTemplateOutlet]=\"breadCrumbComponent.separatorIcon ? breadCrumbComponent.separatorIcon : defaultSeparator\"\n    [ngTemplateOutletContext]=\"{\n      $implicit: this\n    }\"\n  >\n  </ng-template>\n</span>\n\n<ng-template #defaultSeparator>\n  <span class=\"devui-breadcrumb-separator\">/</span>\n</ng-template>\n", styles: [".devui-font-size-base{font-size:12px;font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:12px;font-size:var(--devui-font-size, 12px);font-weight:400;line-height:1.5}.devui-font-size-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px);font-weight:700;line-height:1.5}.devui-font-size-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px);font-weight:700;line-height:1.5}.devui-font-size-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px);font-weight:700;line-height:1.5}.devui-breadcrumb-font-style,.devui-breadcrumb-separator,.devui-breadcrumb-item ::ng-deep a,.devui-breadcrumb-item{font-size:12px;font-size:var(--devui-font-size-sm, 12px);color:#71757f;color:var(--devui-aide-text, #71757f)}.devui-breadcrumb-item{cursor:auto}.devui-breadcrumb-item ::ng-deep a:hover{color:#252b3a;color:var(--devui-text, #252b3a);text-decoration:none}.devui-breadcrumb-item ::ng-deep a{cursor:pointer}.devui-breadcrumb-item ::ng-deep a:focus{text-decoration:none}.devui-breadcrumb-down-icon{vertical-align:middle;display:inline-block;cursor:pointer;width:16px;height:16px;margin-right:-8px;text-align:center;outline:none}.devui-breadcrumb-down-icon svg g path{fill:#71757f;fill:var(--devui-icon-fill, #71757f)}.devui-breadcrumb-item-active{color:#252b3a;color:var(--devui-text, #252b3a)}.devui-breadcrumb-item-active ::ng-deep a{color:#252b3a;color:var(--devui-text, #252b3a);text-decoration:none}.devui-breadcrumb-item-active svg g path{fill:#71757f;fill:var(--devui-icon-text, #71757f)}.devui-breadcrumb-item-active span{color:#252b3a;color:var(--devui-text, #252b3a)}.devui-breadcrumb-separator{margin:0 4px}.devui-breadcrumb-dropdown-menu{padding:8px 0;max-width:200px}.devui-breadcrumb-dropdown-menu li{padding:0 12px;font-size:12px;font-size:var(--devui-font-size, 12px);line-height:36px;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;cursor:pointer}.devui-breadcrumb-dropdown-menu li a{color:#252b3a;color:var(--devui-text, #252b3a);line-height:36px;width:170px;display:inline-block}.devui-breadcrumb-dropdown-menu li a:focus{text-decoration:none}.devui-breadcrumb-dropdown-menu li:hover{background:#f2f2f3;background:var(--devui-list-item-hover-bg, #f2f2f3)}.devui-breadcrumb-dropdown-menu li:hover a{text-decoration:none}.devui-search-container{max-width:200px}span.devui-breadcrumb-dropdown-origin{min-width:unset;display:inline-flex;padding:0}d-search{width:100%}.devui-breadcrumb-item-with-menu .devui-breadcrumb-item{cursor:pointer}.devui-breadcrumb-item-with-menu:hover svg g path{fill:#252b3a;fill:var(--devui-icon-fill-hover, #252b3a)}.devui-dropdown-open .devui-breadcrumb-down-icon{transform:rotate(180deg)}.devui-breadcrumb-item ::ng-deep a,.devui-breadcrumb-item ::ng-deep span{transition:color .3s cubic-bezier(.645,.045,.355,1);transition:color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-breadcrumb-down-icon{transition:transform .3s cubic-bezier(.645,.045,.355,1);transition:transform var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1));transform-origin:center}.devui-breadcrumb-down-icon svg g path{transition:fill .3s cubic-bezier(.645,.045,.355,1);transition:fill var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}\n"], dependencies: [{ kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i3.DropDownDirective, selector: "[dDropDown]", inputs: ["isOpen", "disabled", "showAnimation", "trigger", "closeScope", "closeOnMouseLeaveMenu"], outputs: ["toggleEvent"], exportAs: ["d-dropdown"] }, { kind: "directive", type: i3.DropDownMenuDirective, selector: "[dDropDownMenu]", exportAs: ["d-dropdown-menu"] }, { kind: "directive", type: i3.DropDownToggleDirective, selector: "[dDropDownToggle]", inputs: ["toggleOnFocus", "autoFocus"], exportAs: ["d-dropdown-toggle"] }, { kind: "component", type: i3.DropDownAppendToBodyComponent, selector: "[dDropDown][appendToBody]", inputs: ["alignOrigin", "appendToBodyDirections", "appendToBodyScrollStrategy"] }, { kind: "component", type: i4.SearchComponent, selector: "d-search", inputs: ["size", "placeholder", "maxLength", "isKeyupSearch", "delay", "disabled", "cssClass", "iconPosition", "noBorder", "autoFocus", "styleType"], outputs: ["searchFn"], exportAs: ["search"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: BreadCrumbItemComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, selector: 'd-breadcrumb-item', exportAs: 'dBreadcrumbItem', preserveWhitespaces: false, template: "<ng-container *ngIf=\"showMenu; else breadcrumbContentTpl\">\n  <span\n    class=\"devui-breadcrumb-item-with-menu devui-dropdown-no-border devui-dropdown-origin devui-breadcrumb-dropdown-origin\"\n    dDropDown\n    dDropDownToggle\n    appendToBody\n    trigger=\"hover\"\n    (toggleEvent)=\"onToggle($event)\"\n    [ngClass]=\"{ 'devui-breadcrumb-item-active': isOpen }\"\n  >\n    <ng-template [ngTemplateOutlet]=\"breadcrumbContentTpl\"></ng-template>\n    <i class=\"devui-breadcrumb-down-icon\">\n      <svg\n        width=\"1em\"\n        height=\"1em\"\n        viewBox=\"0 0 16 16\"\n        version=\"1.1\"\n        xmlns=\"http://www.w3.org/2000/svg\"\n        xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n      >\n        <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n          <path\n            d=\"M12.1464466,6.85355339 L8.35355339,10.6464466 C8.15829124,10.8417088 7.84170876,10.8417088 7.64644661,10.6464466 L3.85355339,6.85355339 C3.65829124,6.65829124 3.65829124,6.34170876 3.85355339,6.14644661 C3.94732158,6.05267842 4.07449854,6 4.20710678,6 L11.7928932,6 C12.0690356,6 12.2928932,6.22385763 12.2928932,6.5 C12.2928932,6.63260824 12.2402148,6.7597852 12.1464466,6.85355339 Z\"\n            fill-rule=\"nonzero\"\n          ></path>\n        </g>\n      </svg>\n    </i>\n    <div dDropDownMenu class=\"devui-dropdown-menu\">\n      <ng-template\n        [ngTemplateOutlet]=\"customMenuTemplate ? customMenuTemplate : dropDownMenuTpl\"\n        [ngTemplateOutletContext]=\"{\n          $implicit: this\n        }\"\n      >\n      </ng-template>\n    </div>\n  </span>\n</ng-container>\n\n<ng-template #breadcrumbContentTpl>\n  <span class=\"devui-breadcrumb-item\">\n    <ng-content></ng-content>\n  </span>\n</ng-template>\n\n<ng-template #dropDownMenuTpl>\n  <div *ngIf=\"isSearch\" class=\"devui-search-container\">\n    <d-search [size]=\"'sm'\" (searchFn)=\"searchEvent($event)\" [cssClass]=\"'devui-search-in-dropdown'\"></d-search>\n  </div>\n  <ul class=\"devui-breadcrumb-dropdown-menu\">\n    <li *ngFor=\"let item of menuListDisplay\" title=\"{{ item.name }}\">\n      <a\n        *ngIf=\"!item.linkType || item.linkType === 'hrefLink'\"\n        [href]=\"item.link\"\n        rel=\"noopener\"\n        [target]=\"item.target ? item.target : '_self'\"\n        >{{ item.name }}</a\n      >\n      <a\n        *ngIf=\"item.linkType === 'routerLink'\"\n        rel=\"noopener\"\n        [target]=\"item.target\"\n        [href]=\"item.link\"\n        (click)=\"navigateTo($event, item)\"\n        >{{ item.name }}</a\n      >\n    </li>\n  </ul>\n</ng-template>\n\n<span class=\"devui-breadcrumb-separator\">\n  <ng-template\n    [ngTemplateOutlet]=\"breadCrumbComponent.separatorIcon ? breadCrumbComponent.separatorIcon : defaultSeparator\"\n    [ngTemplateOutletContext]=\"{\n      $implicit: this\n    }\"\n  >\n  </ng-template>\n</span>\n\n<ng-template #defaultSeparator>\n  <span class=\"devui-breadcrumb-separator\">/</span>\n</ng-template>\n", styles: [".devui-font-size-base{font-size:12px;font-size:var(--devui-font-size, 12px)}.devui-font-base{font-size:12px;font-size:var(--devui-font-size, 12px);font-weight:400;line-height:1.5}.devui-font-size-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px)}.devui-font-modal-title{font-size:18px;font-size:var(--devui-font-size-modal-title, 18px);font-weight:700;line-height:1.5}.devui-font-size-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px)}.devui-font-page-title{font-size:16px;font-size:var(--devui-font-size-page-title, 16px);font-weight:700;line-height:1.5}.devui-font-size-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px)}.devui-font-secondary-title{font-size:14px;font-size:var(--devui-font-size-card-title, 14px);font-weight:700;line-height:1.5}.devui-breadcrumb-font-style,.devui-breadcrumb-separator,.devui-breadcrumb-item ::ng-deep a,.devui-breadcrumb-item{font-size:12px;font-size:var(--devui-font-size-sm, 12px);color:#71757f;color:var(--devui-aide-text, #71757f)}.devui-breadcrumb-item{cursor:auto}.devui-breadcrumb-item ::ng-deep a:hover{color:#252b3a;color:var(--devui-text, #252b3a);text-decoration:none}.devui-breadcrumb-item ::ng-deep a{cursor:pointer}.devui-breadcrumb-item ::ng-deep a:focus{text-decoration:none}.devui-breadcrumb-down-icon{vertical-align:middle;display:inline-block;cursor:pointer;width:16px;height:16px;margin-right:-8px;text-align:center;outline:none}.devui-breadcrumb-down-icon svg g path{fill:#71757f;fill:var(--devui-icon-fill, #71757f)}.devui-breadcrumb-item-active{color:#252b3a;color:var(--devui-text, #252b3a)}.devui-breadcrumb-item-active ::ng-deep a{color:#252b3a;color:var(--devui-text, #252b3a);text-decoration:none}.devui-breadcrumb-item-active svg g path{fill:#71757f;fill:var(--devui-icon-text, #71757f)}.devui-breadcrumb-item-active span{color:#252b3a;color:var(--devui-text, #252b3a)}.devui-breadcrumb-separator{margin:0 4px}.devui-breadcrumb-dropdown-menu{padding:8px 0;max-width:200px}.devui-breadcrumb-dropdown-menu li{padding:0 12px;font-size:12px;font-size:var(--devui-font-size, 12px);line-height:36px;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;cursor:pointer}.devui-breadcrumb-dropdown-menu li a{color:#252b3a;color:var(--devui-text, #252b3a);line-height:36px;width:170px;display:inline-block}.devui-breadcrumb-dropdown-menu li a:focus{text-decoration:none}.devui-breadcrumb-dropdown-menu li:hover{background:#f2f2f3;background:var(--devui-list-item-hover-bg, #f2f2f3)}.devui-breadcrumb-dropdown-menu li:hover a{text-decoration:none}.devui-search-container{max-width:200px}span.devui-breadcrumb-dropdown-origin{min-width:unset;display:inline-flex;padding:0}d-search{width:100%}.devui-breadcrumb-item-with-menu .devui-breadcrumb-item{cursor:pointer}.devui-breadcrumb-item-with-menu:hover svg g path{fill:#252b3a;fill:var(--devui-icon-fill-hover, #252b3a)}.devui-dropdown-open .devui-breadcrumb-down-icon{transform:rotate(180deg)}.devui-breadcrumb-item ::ng-deep a,.devui-breadcrumb-item ::ng-deep span{transition:color .3s cubic-bezier(.645,.045,.355,1);transition:color var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}.devui-breadcrumb-down-icon{transition:transform .3s cubic-bezier(.645,.045,.355,1);transition:transform var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1));transform-origin:center}.devui-breadcrumb-down-icon svg g path{transition:fill .3s cubic-bezier(.645,.045,.355,1);transition:fill var(--devui-animation-duration-slow, .3s) var(--devui-animation-ease-in-out-smooth, cubic-bezier(.645, .045, .355, 1))}\n"] }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [BREADCRUMB]
                }] }, { type: BreadCrumbService }]; }, propDecorators: { showMenu: [{
                type: Input
            }], customMenuTemplate: [{
                type: Input
            }], menuList: [{
                type: Input
            }], isSearch: [{
                type: Input
            }], toggleEvent: [{
                type: Output
            }] } });

class BreadCrumbComponent {
    constructor(breadCrumbService) {
        this.breadCrumbService = breadCrumbService;
        this.source = [];
    }
    navigateTo($event, item) {
        this.breadCrumbService.navigateTo($event, item);
    }
}
BreadCrumbComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: BreadCrumbComponent, deps: [{ token: BreadCrumbService }], target: i0.ɵɵFactoryTarget.Component });
BreadCrumbComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.1.5", type: BreadCrumbComponent, selector: "d-breadcrumb", inputs: { separatorIcon: "separatorIcon", source: "source" }, providers: [{
            provide: BREADCRUMB,
            useExisting: forwardRef(() => BreadCrumbComponent)
        }], exportAs: ["dBreadcrumb"], ngImport: i0, template: "<ng-container *ngIf=\"source && source.length\">\n  <d-breadcrumb-item\n    *ngFor=\"let item of source\"\n    [showMenu]=\"item.showMenu\"\n    [isSearch]=\"item.isSearch\"\n    [menuList]=\"item.menuList\"\n    [customMenuTemplate]=\"item.customMenuTemplate\"\n  >\n    <a\n      *ngIf=\"!item.noNavigation && (!item.linkType || item.linkType === 'hrefLink')\"\n      rel=\"noopener\"\n      [href]=\"item.link\"\n      [target]=\"item.target ? item.target : '_self'\"\n      >{{ item.title }}</a\n    >\n    <a\n      *ngIf=\"!item.noNavigation && item.linkType === 'routerLink'\"\n      rel=\"noopener\"\n      [target]=\"item.target\"\n      [href]=\"item.link\"\n      (click)=\"navigateTo($event, item)\"\n      >{{ item.title }}</a\n    >\n    <span *ngIf=\"item.noNavigation\">{{ item.title }}</span>\n  </d-breadcrumb-item>\n</ng-container>\n<ng-container *ngIf=\"!(source && source.length)\">\n  <ng-content></ng-content>\n</ng-container>\n", styles: [":host{display:flex;-webkit-align-items:center;min-height:28px}:host ::ng-deep d-breadcrumb-item:last-child .devui-breadcrumb-item{color:#252b3a;color:var(--devui-text, #252b3a)}:host ::ng-deep d-breadcrumb-item:last-child .devui-breadcrumb-item a{color:#252b3a;color:var(--devui-text, #252b3a)}:host ::ng-deep d-breadcrumb-item:last-child .devui-breadcrumb-separator{display:none}\n"], dependencies: [{ kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: BreadCrumbItemComponent, selector: "d-breadcrumb-item", inputs: ["showMenu", "customMenuTemplate", "menuList", "isSearch"], outputs: ["toggleEvent"], exportAs: ["dBreadcrumbItem"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: BreadCrumbComponent, decorators: [{
            type: Component,
            args: [{ selector: 'd-breadcrumb', exportAs: 'dBreadcrumb', preserveWhitespaces: false, providers: [{
                            provide: BREADCRUMB,
                            useExisting: forwardRef(() => BreadCrumbComponent)
                        }], template: "<ng-container *ngIf=\"source && source.length\">\n  <d-breadcrumb-item\n    *ngFor=\"let item of source\"\n    [showMenu]=\"item.showMenu\"\n    [isSearch]=\"item.isSearch\"\n    [menuList]=\"item.menuList\"\n    [customMenuTemplate]=\"item.customMenuTemplate\"\n  >\n    <a\n      *ngIf=\"!item.noNavigation && (!item.linkType || item.linkType === 'hrefLink')\"\n      rel=\"noopener\"\n      [href]=\"item.link\"\n      [target]=\"item.target ? item.target : '_self'\"\n      >{{ item.title }}</a\n    >\n    <a\n      *ngIf=\"!item.noNavigation && item.linkType === 'routerLink'\"\n      rel=\"noopener\"\n      [target]=\"item.target\"\n      [href]=\"item.link\"\n      (click)=\"navigateTo($event, item)\"\n      >{{ item.title }}</a\n    >\n    <span *ngIf=\"item.noNavigation\">{{ item.title }}</span>\n  </d-breadcrumb-item>\n</ng-container>\n<ng-container *ngIf=\"!(source && source.length)\">\n  <ng-content></ng-content>\n</ng-container>\n", styles: [":host{display:flex;-webkit-align-items:center;min-height:28px}:host ::ng-deep d-breadcrumb-item:last-child .devui-breadcrumb-item{color:#252b3a;color:var(--devui-text, #252b3a)}:host ::ng-deep d-breadcrumb-item:last-child .devui-breadcrumb-item a{color:#252b3a;color:var(--devui-text, #252b3a)}:host ::ng-deep d-breadcrumb-item:last-child .devui-breadcrumb-separator{display:none}\n"] }]
        }], ctorParameters: function () { return [{ type: BreadCrumbService }]; }, propDecorators: { separatorIcon: [{
                type: Input
            }], source: [{
                type: Input
            }] } });

class BreadcrumbModule {
}
BreadcrumbModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: BreadcrumbModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
BreadcrumbModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.1.5", ngImport: i0, type: BreadcrumbModule, declarations: [BreadCrumbComponent, BreadCrumbItemComponent], imports: [CommonModule, RouterModule, DropDownModule, SearchModule], exports: [BreadCrumbComponent, BreadCrumbItemComponent] });
BreadcrumbModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: BreadcrumbModule, providers: [BreadCrumbService], imports: [CommonModule, RouterModule, DropDownModule, SearchModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.5", ngImport: i0, type: BreadcrumbModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, RouterModule, DropDownModule, SearchModule],
                    exports: [BreadCrumbComponent, BreadCrumbItemComponent],
                    declarations: [BreadCrumbComponent, BreadCrumbItemComponent],
                    providers: [BreadCrumbService],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BREADCRUMB, BreadCrumbComponent, BreadCrumbItemComponent, BreadCrumbService, BreadcrumbModule };
//# sourceMappingURL=ng-devui-breadcrumb.mjs.map
